from datadog_api_client.v1.model.api_error_response import APIErrorResponse
from datadog_api_client.v1.model.aws_account import AWSAccount
from datadog_api_client.v1.model.aws_account_and_lambda_request import AWSAccountAndLambdaRequest
from datadog_api_client.v1.model.aws_account_create_response import AWSAccountCreateResponse
from datadog_api_client.v1.model.aws_account_delete_request import AWSAccountDeleteRequest
from datadog_api_client.v1.model.aws_account_list_response import AWSAccountListResponse
from datadog_api_client.v1.model.aws_logs_async_error import AWSLogsAsyncError
from datadog_api_client.v1.model.aws_logs_async_response import AWSLogsAsyncResponse
from datadog_api_client.v1.model.aws_logs_lambda import AWSLogsLambda
from datadog_api_client.v1.model.aws_logs_list_response import AWSLogsListResponse
from datadog_api_client.v1.model.aws_logs_list_services_response import AWSLogsListServicesResponse
from datadog_api_client.v1.model.aws_logs_services_request import AWSLogsServicesRequest
from datadog_api_client.v1.model.aws_namespace import AWSNamespace
from datadog_api_client.v1.model.aws_tag_filter import AWSTagFilter
from datadog_api_client.v1.model.aws_tag_filter_create_request import AWSTagFilterCreateRequest
from datadog_api_client.v1.model.aws_tag_filter_delete_request import AWSTagFilterDeleteRequest
from datadog_api_client.v1.model.aws_tag_filter_list_response import AWSTagFilterListResponse
from datadog_api_client.v1.model.access_role import AccessRole
from datadog_api_client.v1.model.add_signal_to_incident_request import AddSignalToIncidentRequest
from datadog_api_client.v1.model.agent_check import AgentCheck
from datadog_api_client.v1.model.alert_graph_widget_definition import AlertGraphWidgetDefinition
from datadog_api_client.v1.model.alert_graph_widget_definition_type import AlertGraphWidgetDefinitionType
from datadog_api_client.v1.model.alert_value_widget_definition import AlertValueWidgetDefinition
from datadog_api_client.v1.model.alert_value_widget_definition_type import AlertValueWidgetDefinitionType
from datadog_api_client.v1.model.api_key import ApiKey
from datadog_api_client.v1.model.api_key_list_response import ApiKeyListResponse
from datadog_api_client.v1.model.api_key_response import ApiKeyResponse
from datadog_api_client.v1.model.apm_stats_query_column_type import ApmStatsQueryColumnType
from datadog_api_client.v1.model.apm_stats_query_definition import ApmStatsQueryDefinition
from datadog_api_client.v1.model.apm_stats_query_row_type import ApmStatsQueryRowType
from datadog_api_client.v1.model.application_key import ApplicationKey
from datadog_api_client.v1.model.application_key_list_response import ApplicationKeyListResponse
from datadog_api_client.v1.model.application_key_response import ApplicationKeyResponse
from datadog_api_client.v1.model.authentication_validation_response import AuthenticationValidationResponse
from datadog_api_client.v1.model.azure_account import AzureAccount
from datadog_api_client.v1.model.azure_account_list_response import AzureAccountListResponse
from datadog_api_client.v1.model.cancel_downtimes_by_scope_request import CancelDowntimesByScopeRequest
from datadog_api_client.v1.model.canceled_downtimes_ids import CanceledDowntimesIds
from datadog_api_client.v1.model.change_widget_definition import ChangeWidgetDefinition
from datadog_api_client.v1.model.change_widget_definition_type import ChangeWidgetDefinitionType
from datadog_api_client.v1.model.change_widget_request import ChangeWidgetRequest
from datadog_api_client.v1.model.check_can_delete_monitor_response import CheckCanDeleteMonitorResponse
from datadog_api_client.v1.model.check_can_delete_monitor_response_data import CheckCanDeleteMonitorResponseData
from datadog_api_client.v1.model.check_can_delete_slo_response import CheckCanDeleteSLOResponse
from datadog_api_client.v1.model.check_can_delete_slo_response_data import CheckCanDeleteSLOResponseData
from datadog_api_client.v1.model.check_status_widget_definition import CheckStatusWidgetDefinition
from datadog_api_client.v1.model.check_status_widget_definition_type import CheckStatusWidgetDefinitionType
from datadog_api_client.v1.model.content_encoding import ContentEncoding
from datadog_api_client.v1.model.creator import Creator
from datadog_api_client.v1.model.dashboard import Dashboard
from datadog_api_client.v1.model.dashboard_bulk_action_data import DashboardBulkActionData
from datadog_api_client.v1.model.dashboard_bulk_action_data_list import DashboardBulkActionDataList
from datadog_api_client.v1.model.dashboard_bulk_delete_request import DashboardBulkDeleteRequest
from datadog_api_client.v1.model.dashboard_delete_response import DashboardDeleteResponse
from datadog_api_client.v1.model.dashboard_layout_type import DashboardLayoutType
from datadog_api_client.v1.model.dashboard_list import DashboardList
from datadog_api_client.v1.model.dashboard_list_delete_response import DashboardListDeleteResponse
from datadog_api_client.v1.model.dashboard_list_list_response import DashboardListListResponse
from datadog_api_client.v1.model.dashboard_reflow_type import DashboardReflowType
from datadog_api_client.v1.model.dashboard_resource_type import DashboardResourceType
from datadog_api_client.v1.model.dashboard_restore_request import DashboardRestoreRequest
from datadog_api_client.v1.model.dashboard_summary import DashboardSummary
from datadog_api_client.v1.model.dashboard_summary_definition import DashboardSummaryDefinition
from datadog_api_client.v1.model.dashboard_template_variable import DashboardTemplateVariable
from datadog_api_client.v1.model.dashboard_template_variable_preset import DashboardTemplateVariablePreset
from datadog_api_client.v1.model.dashboard_template_variable_preset_value import DashboardTemplateVariablePresetValue
from datadog_api_client.v1.model.deleted_monitor import DeletedMonitor
from datadog_api_client.v1.model.distribution_point import DistributionPoint
from datadog_api_client.v1.model.distribution_points_content_encoding import DistributionPointsContentEncoding
from datadog_api_client.v1.model.distribution_points_payload import DistributionPointsPayload
from datadog_api_client.v1.model.distribution_points_series import DistributionPointsSeries
from datadog_api_client.v1.model.distribution_points_type import DistributionPointsType
from datadog_api_client.v1.model.distribution_widget_definition import DistributionWidgetDefinition
from datadog_api_client.v1.model.distribution_widget_definition_type import DistributionWidgetDefinitionType
from datadog_api_client.v1.model.distribution_widget_histogram_request_query import (
    DistributionWidgetHistogramRequestQuery,
)
from datadog_api_client.v1.model.distribution_widget_histogram_request_type import (
    DistributionWidgetHistogramRequestType,
)
from datadog_api_client.v1.model.distribution_widget_request import DistributionWidgetRequest
from datadog_api_client.v1.model.distribution_widget_x_axis import DistributionWidgetXAxis
from datadog_api_client.v1.model.distribution_widget_y_axis import DistributionWidgetYAxis
from datadog_api_client.v1.model.downtime import Downtime
from datadog_api_client.v1.model.downtime_child import DowntimeChild
from datadog_api_client.v1.model.downtime_recurrence import DowntimeRecurrence
from datadog_api_client.v1.model.event import Event
from datadog_api_client.v1.model.event_alert_type import EventAlertType
from datadog_api_client.v1.model.event_create_request import EventCreateRequest
from datadog_api_client.v1.model.event_create_response import EventCreateResponse
from datadog_api_client.v1.model.event_list_response import EventListResponse
from datadog_api_client.v1.model.event_priority import EventPriority
from datadog_api_client.v1.model.event_query_definition import EventQueryDefinition
from datadog_api_client.v1.model.event_response import EventResponse
from datadog_api_client.v1.model.event_stream_widget_definition import EventStreamWidgetDefinition
from datadog_api_client.v1.model.event_stream_widget_definition_type import EventStreamWidgetDefinitionType
from datadog_api_client.v1.model.event_timeline_widget_definition import EventTimelineWidgetDefinition
from datadog_api_client.v1.model.event_timeline_widget_definition_type import EventTimelineWidgetDefinitionType
from datadog_api_client.v1.model.formula_and_function_apm_dependency_stat_name import (
    FormulaAndFunctionApmDependencyStatName,
)
from datadog_api_client.v1.model.formula_and_function_apm_dependency_stats_data_source import (
    FormulaAndFunctionApmDependencyStatsDataSource,
)
from datadog_api_client.v1.model.formula_and_function_apm_dependency_stats_query_definition import (
    FormulaAndFunctionApmDependencyStatsQueryDefinition,
)
from datadog_api_client.v1.model.formula_and_function_apm_resource_stat_name import (
    FormulaAndFunctionApmResourceStatName,
)
from datadog_api_client.v1.model.formula_and_function_apm_resource_stats_data_source import (
    FormulaAndFunctionApmResourceStatsDataSource,
)
from datadog_api_client.v1.model.formula_and_function_apm_resource_stats_query_definition import (
    FormulaAndFunctionApmResourceStatsQueryDefinition,
)
from datadog_api_client.v1.model.formula_and_function_event_aggregation import FormulaAndFunctionEventAggregation
from datadog_api_client.v1.model.formula_and_function_event_query_definition import (
    FormulaAndFunctionEventQueryDefinition,
)
from datadog_api_client.v1.model.formula_and_function_event_query_definition_compute import (
    FormulaAndFunctionEventQueryDefinitionCompute,
)
from datadog_api_client.v1.model.formula_and_function_event_query_definition_search import (
    FormulaAndFunctionEventQueryDefinitionSearch,
)
from datadog_api_client.v1.model.formula_and_function_event_query_group_by import FormulaAndFunctionEventQueryGroupBy
from datadog_api_client.v1.model.formula_and_function_event_query_group_by_sort import (
    FormulaAndFunctionEventQueryGroupBySort,
)
from datadog_api_client.v1.model.formula_and_function_events_data_source import FormulaAndFunctionEventsDataSource
from datadog_api_client.v1.model.formula_and_function_metric_aggregation import FormulaAndFunctionMetricAggregation
from datadog_api_client.v1.model.formula_and_function_metric_data_source import FormulaAndFunctionMetricDataSource
from datadog_api_client.v1.model.formula_and_function_metric_query_definition import (
    FormulaAndFunctionMetricQueryDefinition,
)
from datadog_api_client.v1.model.formula_and_function_process_query_data_source import (
    FormulaAndFunctionProcessQueryDataSource,
)
from datadog_api_client.v1.model.formula_and_function_process_query_definition import (
    FormulaAndFunctionProcessQueryDefinition,
)
from datadog_api_client.v1.model.formula_and_function_query_definition import FormulaAndFunctionQueryDefinition
from datadog_api_client.v1.model.formula_and_function_response_format import FormulaAndFunctionResponseFormat
from datadog_api_client.v1.model.free_text_widget_definition import FreeTextWidgetDefinition
from datadog_api_client.v1.model.free_text_widget_definition_type import FreeTextWidgetDefinitionType
from datadog_api_client.v1.model.funnel_query import FunnelQuery
from datadog_api_client.v1.model.funnel_request_type import FunnelRequestType
from datadog_api_client.v1.model.funnel_source import FunnelSource
from datadog_api_client.v1.model.funnel_step import FunnelStep
from datadog_api_client.v1.model.funnel_widget_definition import FunnelWidgetDefinition
from datadog_api_client.v1.model.funnel_widget_definition_type import FunnelWidgetDefinitionType
from datadog_api_client.v1.model.funnel_widget_request import FunnelWidgetRequest
from datadog_api_client.v1.model.gcp_account import GCPAccount
from datadog_api_client.v1.model.gcp_account_list_response import GCPAccountListResponse
from datadog_api_client.v1.model.geomap_widget_definition import GeomapWidgetDefinition
from datadog_api_client.v1.model.geomap_widget_definition_style import GeomapWidgetDefinitionStyle
from datadog_api_client.v1.model.geomap_widget_definition_type import GeomapWidgetDefinitionType
from datadog_api_client.v1.model.geomap_widget_definition_view import GeomapWidgetDefinitionView
from datadog_api_client.v1.model.geomap_widget_request import GeomapWidgetRequest
from datadog_api_client.v1.model.graph_snapshot import GraphSnapshot
from datadog_api_client.v1.model.group_widget_definition import GroupWidgetDefinition
from datadog_api_client.v1.model.group_widget_definition_type import GroupWidgetDefinitionType
from datadog_api_client.v1.model.http_log import HTTPLog
from datadog_api_client.v1.model.http_log_error import HTTPLogError
from datadog_api_client.v1.model.http_log_item import HTTPLogItem
from datadog_api_client.v1.model.heat_map_widget_definition import HeatMapWidgetDefinition
from datadog_api_client.v1.model.heat_map_widget_definition_type import HeatMapWidgetDefinitionType
from datadog_api_client.v1.model.heat_map_widget_request import HeatMapWidgetRequest
from datadog_api_client.v1.model.host import Host
from datadog_api_client.v1.model.host_list_response import HostListResponse
from datadog_api_client.v1.model.host_map_request import HostMapRequest
from datadog_api_client.v1.model.host_map_widget_definition import HostMapWidgetDefinition
from datadog_api_client.v1.model.host_map_widget_definition_requests import HostMapWidgetDefinitionRequests
from datadog_api_client.v1.model.host_map_widget_definition_style import HostMapWidgetDefinitionStyle
from datadog_api_client.v1.model.host_map_widget_definition_type import HostMapWidgetDefinitionType
from datadog_api_client.v1.model.host_meta import HostMeta
from datadog_api_client.v1.model.host_meta_install_method import HostMetaInstallMethod
from datadog_api_client.v1.model.host_metrics import HostMetrics
from datadog_api_client.v1.model.host_mute_response import HostMuteResponse
from datadog_api_client.v1.model.host_mute_settings import HostMuteSettings
from datadog_api_client.v1.model.host_tags import HostTags
from datadog_api_client.v1.model.host_totals import HostTotals
from datadog_api_client.v1.model.hourly_usage_attribution_body import HourlyUsageAttributionBody
from datadog_api_client.v1.model.hourly_usage_attribution_metadata import HourlyUsageAttributionMetadata
from datadog_api_client.v1.model.hourly_usage_attribution_pagination import HourlyUsageAttributionPagination
from datadog_api_client.v1.model.hourly_usage_attribution_response import HourlyUsageAttributionResponse
from datadog_api_client.v1.model.hourly_usage_attribution_usage_type import HourlyUsageAttributionUsageType
from datadog_api_client.v1.model.i_frame_widget_definition import IFrameWidgetDefinition
from datadog_api_client.v1.model.i_frame_widget_definition_type import IFrameWidgetDefinitionType
from datadog_api_client.v1.model.ip_prefixes_api import IPPrefixesAPI
from datadog_api_client.v1.model.ip_prefixes_apm import IPPrefixesAPM
from datadog_api_client.v1.model.ip_prefixes_agents import IPPrefixesAgents
from datadog_api_client.v1.model.ip_prefixes_logs import IPPrefixesLogs
from datadog_api_client.v1.model.ip_prefixes_process import IPPrefixesProcess
from datadog_api_client.v1.model.ip_prefixes_synthetics import IPPrefixesSynthetics
from datadog_api_client.v1.model.ip_prefixes_synthetics_private_locations import IPPrefixesSyntheticsPrivateLocations
from datadog_api_client.v1.model.ip_prefixes_webhooks import IPPrefixesWebhooks
from datadog_api_client.v1.model.ip_ranges import IPRanges
from datadog_api_client.v1.model.idp_form_data import IdpFormData
from datadog_api_client.v1.model.idp_response import IdpResponse
from datadog_api_client.v1.model.image_widget_definition import ImageWidgetDefinition
from datadog_api_client.v1.model.image_widget_definition_type import ImageWidgetDefinitionType
from datadog_api_client.v1.model.intake_payload_accepted import IntakePayloadAccepted
from datadog_api_client.v1.model.list_stream_column import ListStreamColumn
from datadog_api_client.v1.model.list_stream_column_width import ListStreamColumnWidth
from datadog_api_client.v1.model.list_stream_query import ListStreamQuery
from datadog_api_client.v1.model.list_stream_response_format import ListStreamResponseFormat
from datadog_api_client.v1.model.list_stream_source import ListStreamSource
from datadog_api_client.v1.model.list_stream_widget_definition import ListStreamWidgetDefinition
from datadog_api_client.v1.model.list_stream_widget_definition_type import ListStreamWidgetDefinitionType
from datadog_api_client.v1.model.list_stream_widget_request import ListStreamWidgetRequest
from datadog_api_client.v1.model.log import Log
from datadog_api_client.v1.model.log_content import LogContent
from datadog_api_client.v1.model.log_query_definition import LogQueryDefinition
from datadog_api_client.v1.model.log_query_definition_group_by import LogQueryDefinitionGroupBy
from datadog_api_client.v1.model.log_query_definition_group_by_sort import LogQueryDefinitionGroupBySort
from datadog_api_client.v1.model.log_query_definition_search import LogQueryDefinitionSearch
from datadog_api_client.v1.model.log_stream_widget_definition import LogStreamWidgetDefinition
from datadog_api_client.v1.model.log_stream_widget_definition_type import LogStreamWidgetDefinitionType
from datadog_api_client.v1.model.logs_api_error import LogsAPIError
from datadog_api_client.v1.model.logs_api_error_response import LogsAPIErrorResponse
from datadog_api_client.v1.model.logs_arithmetic_processor import LogsArithmeticProcessor
from datadog_api_client.v1.model.logs_arithmetic_processor_type import LogsArithmeticProcessorType
from datadog_api_client.v1.model.logs_attribute_remapper import LogsAttributeRemapper
from datadog_api_client.v1.model.logs_attribute_remapper_type import LogsAttributeRemapperType
from datadog_api_client.v1.model.logs_by_retention import LogsByRetention
from datadog_api_client.v1.model.logs_by_retention_monthly_usage import LogsByRetentionMonthlyUsage
from datadog_api_client.v1.model.logs_by_retention_org_usage import LogsByRetentionOrgUsage
from datadog_api_client.v1.model.logs_by_retention_orgs import LogsByRetentionOrgs
from datadog_api_client.v1.model.logs_category_processor import LogsCategoryProcessor
from datadog_api_client.v1.model.logs_category_processor_category import LogsCategoryProcessorCategory
from datadog_api_client.v1.model.logs_category_processor_type import LogsCategoryProcessorType
from datadog_api_client.v1.model.logs_date_remapper import LogsDateRemapper
from datadog_api_client.v1.model.logs_date_remapper_type import LogsDateRemapperType
from datadog_api_client.v1.model.logs_exclusion import LogsExclusion
from datadog_api_client.v1.model.logs_exclusion_filter import LogsExclusionFilter
from datadog_api_client.v1.model.logs_filter import LogsFilter
from datadog_api_client.v1.model.logs_geo_ip_parser import LogsGeoIPParser
from datadog_api_client.v1.model.logs_geo_ip_parser_type import LogsGeoIPParserType
from datadog_api_client.v1.model.logs_grok_parser import LogsGrokParser
from datadog_api_client.v1.model.logs_grok_parser_rules import LogsGrokParserRules
from datadog_api_client.v1.model.logs_grok_parser_type import LogsGrokParserType
from datadog_api_client.v1.model.logs_index import LogsIndex
from datadog_api_client.v1.model.logs_index_list_response import LogsIndexListResponse
from datadog_api_client.v1.model.logs_index_update_request import LogsIndexUpdateRequest
from datadog_api_client.v1.model.logs_indexes_order import LogsIndexesOrder
from datadog_api_client.v1.model.logs_list_request import LogsListRequest
from datadog_api_client.v1.model.logs_list_request_time import LogsListRequestTime
from datadog_api_client.v1.model.logs_list_response import LogsListResponse
from datadog_api_client.v1.model.logs_lookup_processor import LogsLookupProcessor
from datadog_api_client.v1.model.logs_lookup_processor_type import LogsLookupProcessorType
from datadog_api_client.v1.model.logs_message_remapper import LogsMessageRemapper
from datadog_api_client.v1.model.logs_message_remapper_type import LogsMessageRemapperType
from datadog_api_client.v1.model.logs_pipeline import LogsPipeline
from datadog_api_client.v1.model.logs_pipeline_list import LogsPipelineList
from datadog_api_client.v1.model.logs_pipeline_processor import LogsPipelineProcessor
from datadog_api_client.v1.model.logs_pipeline_processor_type import LogsPipelineProcessorType
from datadog_api_client.v1.model.logs_pipelines_order import LogsPipelinesOrder
from datadog_api_client.v1.model.logs_processor import LogsProcessor
from datadog_api_client.v1.model.logs_query_compute import LogsQueryCompute
from datadog_api_client.v1.model.logs_retention_agg_sum_usage import LogsRetentionAggSumUsage
from datadog_api_client.v1.model.logs_retention_sum_usage import LogsRetentionSumUsage
from datadog_api_client.v1.model.logs_service_remapper import LogsServiceRemapper
from datadog_api_client.v1.model.logs_service_remapper_type import LogsServiceRemapperType
from datadog_api_client.v1.model.logs_sort import LogsSort
from datadog_api_client.v1.model.logs_status_remapper import LogsStatusRemapper
from datadog_api_client.v1.model.logs_status_remapper_type import LogsStatusRemapperType
from datadog_api_client.v1.model.logs_string_builder_processor import LogsStringBuilderProcessor
from datadog_api_client.v1.model.logs_string_builder_processor_type import LogsStringBuilderProcessorType
from datadog_api_client.v1.model.logs_trace_remapper import LogsTraceRemapper
from datadog_api_client.v1.model.logs_trace_remapper_type import LogsTraceRemapperType
from datadog_api_client.v1.model.logs_url_parser import LogsURLParser
from datadog_api_client.v1.model.logs_url_parser_type import LogsURLParserType
from datadog_api_client.v1.model.logs_user_agent_parser import LogsUserAgentParser
from datadog_api_client.v1.model.logs_user_agent_parser_type import LogsUserAgentParserType
from datadog_api_client.v1.model.metric_content_encoding import MetricContentEncoding
from datadog_api_client.v1.model.metric_metadata import MetricMetadata
from datadog_api_client.v1.model.metric_search_response import MetricSearchResponse
from datadog_api_client.v1.model.metric_search_response_results import MetricSearchResponseResults
from datadog_api_client.v1.model.metrics_list_response import MetricsListResponse
from datadog_api_client.v1.model.metrics_payload import MetricsPayload
from datadog_api_client.v1.model.metrics_query_metadata import MetricsQueryMetadata
from datadog_api_client.v1.model.metrics_query_response import MetricsQueryResponse
from datadog_api_client.v1.model.metrics_query_unit import MetricsQueryUnit
from datadog_api_client.v1.model.monitor import Monitor
from datadog_api_client.v1.model.monitor_device_id import MonitorDeviceID
from datadog_api_client.v1.model.monitor_formula_and_function_event_aggregation import (
    MonitorFormulaAndFunctionEventAggregation,
)
from datadog_api_client.v1.model.monitor_formula_and_function_event_query_definition import (
    MonitorFormulaAndFunctionEventQueryDefinition,
)
from datadog_api_client.v1.model.monitor_formula_and_function_event_query_definition_compute import (
    MonitorFormulaAndFunctionEventQueryDefinitionCompute,
)
from datadog_api_client.v1.model.monitor_formula_and_function_event_query_definition_search import (
    MonitorFormulaAndFunctionEventQueryDefinitionSearch,
)
from datadog_api_client.v1.model.monitor_formula_and_function_event_query_group_by import (
    MonitorFormulaAndFunctionEventQueryGroupBy,
)
from datadog_api_client.v1.model.monitor_formula_and_function_event_query_group_by_sort import (
    MonitorFormulaAndFunctionEventQueryGroupBySort,
)
from datadog_api_client.v1.model.monitor_formula_and_function_events_data_source import (
    MonitorFormulaAndFunctionEventsDataSource,
)
from datadog_api_client.v1.model.monitor_formula_and_function_query_definition import (
    MonitorFormulaAndFunctionQueryDefinition,
)
from datadog_api_client.v1.model.monitor_group_search_response import MonitorGroupSearchResponse
from datadog_api_client.v1.model.monitor_group_search_response_counts import MonitorGroupSearchResponseCounts
from datadog_api_client.v1.model.monitor_group_search_result import MonitorGroupSearchResult
from datadog_api_client.v1.model.monitor_options import MonitorOptions
from datadog_api_client.v1.model.monitor_options_aggregation import MonitorOptionsAggregation
from datadog_api_client.v1.model.monitor_options_scheduling_options import MonitorOptionsSchedulingOptions
from datadog_api_client.v1.model.monitor_options_scheduling_options_evaluation_window import (
    MonitorOptionsSchedulingOptionsEvaluationWindow,
)
from datadog_api_client.v1.model.monitor_overall_states import MonitorOverallStates
from datadog_api_client.v1.model.monitor_renotify_status_type import MonitorRenotifyStatusType
from datadog_api_client.v1.model.monitor_search_count import MonitorSearchCount
from datadog_api_client.v1.model.monitor_search_response import MonitorSearchResponse
from datadog_api_client.v1.model.monitor_search_response_counts import MonitorSearchResponseCounts
from datadog_api_client.v1.model.monitor_search_response_metadata import MonitorSearchResponseMetadata
from datadog_api_client.v1.model.monitor_search_result import MonitorSearchResult
from datadog_api_client.v1.model.monitor_search_result_notification import MonitorSearchResultNotification
from datadog_api_client.v1.model.monitor_state import MonitorState
from datadog_api_client.v1.model.monitor_state_group import MonitorStateGroup
from datadog_api_client.v1.model.monitor_summary_widget_definition import MonitorSummaryWidgetDefinition
from datadog_api_client.v1.model.monitor_summary_widget_definition_type import MonitorSummaryWidgetDefinitionType
from datadog_api_client.v1.model.monitor_threshold_window_options import MonitorThresholdWindowOptions
from datadog_api_client.v1.model.monitor_thresholds import MonitorThresholds
from datadog_api_client.v1.model.monitor_type import MonitorType
from datadog_api_client.v1.model.monitor_update_request import MonitorUpdateRequest
from datadog_api_client.v1.model.monthly_usage_attribution_body import MonthlyUsageAttributionBody
from datadog_api_client.v1.model.monthly_usage_attribution_metadata import MonthlyUsageAttributionMetadata
from datadog_api_client.v1.model.monthly_usage_attribution_pagination import MonthlyUsageAttributionPagination
from datadog_api_client.v1.model.monthly_usage_attribution_response import MonthlyUsageAttributionResponse
from datadog_api_client.v1.model.monthly_usage_attribution_supported_metrics import (
    MonthlyUsageAttributionSupportedMetrics,
)
from datadog_api_client.v1.model.monthly_usage_attribution_values import MonthlyUsageAttributionValues
from datadog_api_client.v1.model.note_widget_definition import NoteWidgetDefinition
from datadog_api_client.v1.model.note_widget_definition_type import NoteWidgetDefinitionType
from datadog_api_client.v1.model.notebook_absolute_time import NotebookAbsoluteTime
from datadog_api_client.v1.model.notebook_author import NotebookAuthor
from datadog_api_client.v1.model.notebook_cell_create_request import NotebookCellCreateRequest
from datadog_api_client.v1.model.notebook_cell_create_request_attributes import NotebookCellCreateRequestAttributes
from datadog_api_client.v1.model.notebook_cell_resource_type import NotebookCellResourceType
from datadog_api_client.v1.model.notebook_cell_response import NotebookCellResponse
from datadog_api_client.v1.model.notebook_cell_response_attributes import NotebookCellResponseAttributes
from datadog_api_client.v1.model.notebook_cell_time import NotebookCellTime
from datadog_api_client.v1.model.notebook_cell_update_request import NotebookCellUpdateRequest
from datadog_api_client.v1.model.notebook_cell_update_request_attributes import NotebookCellUpdateRequestAttributes
from datadog_api_client.v1.model.notebook_create_data import NotebookCreateData
from datadog_api_client.v1.model.notebook_create_data_attributes import NotebookCreateDataAttributes
from datadog_api_client.v1.model.notebook_create_request import NotebookCreateRequest
from datadog_api_client.v1.model.notebook_distribution_cell_attributes import NotebookDistributionCellAttributes
from datadog_api_client.v1.model.notebook_global_time import NotebookGlobalTime
from datadog_api_client.v1.model.notebook_graph_size import NotebookGraphSize
from datadog_api_client.v1.model.notebook_heat_map_cell_attributes import NotebookHeatMapCellAttributes
from datadog_api_client.v1.model.notebook_log_stream_cell_attributes import NotebookLogStreamCellAttributes
from datadog_api_client.v1.model.notebook_markdown_cell_attributes import NotebookMarkdownCellAttributes
from datadog_api_client.v1.model.notebook_markdown_cell_definition import NotebookMarkdownCellDefinition
from datadog_api_client.v1.model.notebook_markdown_cell_definition_type import NotebookMarkdownCellDefinitionType
from datadog_api_client.v1.model.notebook_metadata import NotebookMetadata
from datadog_api_client.v1.model.notebook_metadata_type import NotebookMetadataType
from datadog_api_client.v1.model.notebook_relative_time import NotebookRelativeTime
from datadog_api_client.v1.model.notebook_resource_type import NotebookResourceType
from datadog_api_client.v1.model.notebook_response import NotebookResponse
from datadog_api_client.v1.model.notebook_response_data import NotebookResponseData
from datadog_api_client.v1.model.notebook_response_data_attributes import NotebookResponseDataAttributes
from datadog_api_client.v1.model.notebook_split_by import NotebookSplitBy
from datadog_api_client.v1.model.notebook_status import NotebookStatus
from datadog_api_client.v1.model.notebook_timeseries_cell_attributes import NotebookTimeseriesCellAttributes
from datadog_api_client.v1.model.notebook_toplist_cell_attributes import NotebookToplistCellAttributes
from datadog_api_client.v1.model.notebook_update_cell import NotebookUpdateCell
from datadog_api_client.v1.model.notebook_update_data import NotebookUpdateData
from datadog_api_client.v1.model.notebook_update_data_attributes import NotebookUpdateDataAttributes
from datadog_api_client.v1.model.notebook_update_request import NotebookUpdateRequest
from datadog_api_client.v1.model.notebooks_response import NotebooksResponse
from datadog_api_client.v1.model.notebooks_response_data import NotebooksResponseData
from datadog_api_client.v1.model.notebooks_response_data_attributes import NotebooksResponseDataAttributes
from datadog_api_client.v1.model.notebooks_response_meta import NotebooksResponseMeta
from datadog_api_client.v1.model.notebooks_response_page import NotebooksResponsePage
from datadog_api_client.v1.model.on_missing_data_option import OnMissingDataOption
from datadog_api_client.v1.model.org_downgraded_response import OrgDowngradedResponse
from datadog_api_client.v1.model.organization import Organization
from datadog_api_client.v1.model.organization_billing import OrganizationBilling
from datadog_api_client.v1.model.organization_create_body import OrganizationCreateBody
from datadog_api_client.v1.model.organization_create_response import OrganizationCreateResponse
from datadog_api_client.v1.model.organization_list_response import OrganizationListResponse
from datadog_api_client.v1.model.organization_response import OrganizationResponse
from datadog_api_client.v1.model.organization_settings import OrganizationSettings
from datadog_api_client.v1.model.organization_settings_saml import OrganizationSettingsSaml
from datadog_api_client.v1.model.organization_settings_saml_autocreate_users_domains import (
    OrganizationSettingsSamlAutocreateUsersDomains,
)
from datadog_api_client.v1.model.organization_settings_saml_idp_initiated_login import (
    OrganizationSettingsSamlIdpInitiatedLogin,
)
from datadog_api_client.v1.model.organization_settings_saml_strict_mode import OrganizationSettingsSamlStrictMode
from datadog_api_client.v1.model.organization_subscription import OrganizationSubscription
from datadog_api_client.v1.model.pager_duty_service import PagerDutyService
from datadog_api_client.v1.model.pager_duty_service_key import PagerDutyServiceKey
from datadog_api_client.v1.model.pager_duty_service_name import PagerDutyServiceName
from datadog_api_client.v1.model.pagination import Pagination
from datadog_api_client.v1.model.point import Point
from datadog_api_client.v1.model.process_query_definition import ProcessQueryDefinition
from datadog_api_client.v1.model.query_sort_order import QuerySortOrder
from datadog_api_client.v1.model.query_value_widget_definition import QueryValueWidgetDefinition
from datadog_api_client.v1.model.query_value_widget_definition_type import QueryValueWidgetDefinitionType
from datadog_api_client.v1.model.query_value_widget_request import QueryValueWidgetRequest
from datadog_api_client.v1.model.reference_table_logs_lookup_processor import ReferenceTableLogsLookupProcessor
from datadog_api_client.v1.model.response_meta_attributes import ResponseMetaAttributes
from datadog_api_client.v1.model.slo_bulk_delete import SLOBulkDelete
from datadog_api_client.v1.model.slo_bulk_delete_error import SLOBulkDeleteError
from datadog_api_client.v1.model.slo_bulk_delete_response import SLOBulkDeleteResponse
from datadog_api_client.v1.model.slo_bulk_delete_response_data import SLOBulkDeleteResponseData
from datadog_api_client.v1.model.slo_correction import SLOCorrection
from datadog_api_client.v1.model.slo_correction_category import SLOCorrectionCategory
from datadog_api_client.v1.model.slo_correction_create_data import SLOCorrectionCreateData
from datadog_api_client.v1.model.slo_correction_create_request import SLOCorrectionCreateRequest
from datadog_api_client.v1.model.slo_correction_create_request_attributes import SLOCorrectionCreateRequestAttributes
from datadog_api_client.v1.model.slo_correction_list_response import SLOCorrectionListResponse
from datadog_api_client.v1.model.slo_correction_response import SLOCorrectionResponse
from datadog_api_client.v1.model.slo_correction_response_attributes import SLOCorrectionResponseAttributes
from datadog_api_client.v1.model.slo_correction_response_attributes_modifier import (
    SLOCorrectionResponseAttributesModifier,
)
from datadog_api_client.v1.model.slo_correction_type import SLOCorrectionType
from datadog_api_client.v1.model.slo_correction_update_data import SLOCorrectionUpdateData
from datadog_api_client.v1.model.slo_correction_update_request import SLOCorrectionUpdateRequest
from datadog_api_client.v1.model.slo_correction_update_request_attributes import SLOCorrectionUpdateRequestAttributes
from datadog_api_client.v1.model.slo_creator import SLOCreator
from datadog_api_client.v1.model.slo_delete_response import SLODeleteResponse
from datadog_api_client.v1.model.slo_error_budget_remaining_data import SLOErrorBudgetRemainingData
from datadog_api_client.v1.model.slo_error_timeframe import SLOErrorTimeframe
from datadog_api_client.v1.model.slo_history_metrics import SLOHistoryMetrics
from datadog_api_client.v1.model.slo_history_metrics_series import SLOHistoryMetricsSeries
from datadog_api_client.v1.model.slo_history_metrics_series_metadata import SLOHistoryMetricsSeriesMetadata
from datadog_api_client.v1.model.slo_history_metrics_series_metadata_unit import SLOHistoryMetricsSeriesMetadataUnit
from datadog_api_client.v1.model.slo_history_monitor import SLOHistoryMonitor
from datadog_api_client.v1.model.slo_history_response import SLOHistoryResponse
from datadog_api_client.v1.model.slo_history_response_data import SLOHistoryResponseData
from datadog_api_client.v1.model.slo_history_response_error import SLOHistoryResponseError
from datadog_api_client.v1.model.slo_history_response_error_with_type import SLOHistoryResponseErrorWithType
from datadog_api_client.v1.model.slo_history_sli_data import SLOHistorySLIData
from datadog_api_client.v1.model.slo_list_response import SLOListResponse
from datadog_api_client.v1.model.slo_list_response_metadata import SLOListResponseMetadata
from datadog_api_client.v1.model.slo_list_response_metadata_page import SLOListResponseMetadataPage
from datadog_api_client.v1.model.slo_list_widget_definition import SLOListWidgetDefinition
from datadog_api_client.v1.model.slo_list_widget_definition_type import SLOListWidgetDefinitionType
from datadog_api_client.v1.model.slo_list_widget_query import SLOListWidgetQuery
from datadog_api_client.v1.model.slo_list_widget_request import SLOListWidgetRequest
from datadog_api_client.v1.model.slo_list_widget_request_type import SLOListWidgetRequestType
from datadog_api_client.v1.model.slo_overall_statuses import SLOOverallStatuses
from datadog_api_client.v1.model.slo_raw_error_budget_remaining import SLORawErrorBudgetRemaining
from datadog_api_client.v1.model.slo_response import SLOResponse
from datadog_api_client.v1.model.slo_response_data import SLOResponseData
from datadog_api_client.v1.model.slo_threshold import SLOThreshold
from datadog_api_client.v1.model.slo_timeframe import SLOTimeframe
from datadog_api_client.v1.model.slo_type import SLOType
from datadog_api_client.v1.model.slo_type_numeric import SLOTypeNumeric
from datadog_api_client.v1.model.slo_widget_definition import SLOWidgetDefinition
from datadog_api_client.v1.model.slo_widget_definition_type import SLOWidgetDefinitionType
from datadog_api_client.v1.model.scatter_plot_request import ScatterPlotRequest
from datadog_api_client.v1.model.scatter_plot_widget_definition import ScatterPlotWidgetDefinition
from datadog_api_client.v1.model.scatter_plot_widget_definition_requests import ScatterPlotWidgetDefinitionRequests
from datadog_api_client.v1.model.scatter_plot_widget_definition_type import ScatterPlotWidgetDefinitionType
from datadog_api_client.v1.model.scatterplot_dimension import ScatterplotDimension
from datadog_api_client.v1.model.scatterplot_table_request import ScatterplotTableRequest
from datadog_api_client.v1.model.scatterplot_widget_aggregator import ScatterplotWidgetAggregator
from datadog_api_client.v1.model.scatterplot_widget_formula import ScatterplotWidgetFormula
from datadog_api_client.v1.model.search_slo_query import SearchSLOQuery
from datadog_api_client.v1.model.search_slo_response import SearchSLOResponse
from datadog_api_client.v1.model.search_slo_response_data import SearchSLOResponseData
from datadog_api_client.v1.model.search_slo_response_data_attributes import SearchSLOResponseDataAttributes
from datadog_api_client.v1.model.search_slo_response_data_attributes_facets import SearchSLOResponseDataAttributesFacets
from datadog_api_client.v1.model.search_slo_response_data_attributes_facets_object_int import (
    SearchSLOResponseDataAttributesFacetsObjectInt,
)
from datadog_api_client.v1.model.search_slo_response_data_attributes_facets_object_string import (
    SearchSLOResponseDataAttributesFacetsObjectString,
)
from datadog_api_client.v1.model.search_slo_response_links import SearchSLOResponseLinks
from datadog_api_client.v1.model.search_slo_response_meta import SearchSLOResponseMeta
from datadog_api_client.v1.model.search_slo_response_meta_page import SearchSLOResponseMetaPage
from datadog_api_client.v1.model.search_slo_threshold import SearchSLOThreshold
from datadog_api_client.v1.model.search_slo_timeframe import SearchSLOTimeframe
from datadog_api_client.v1.model.search_service_level_objective import SearchServiceLevelObjective
from datadog_api_client.v1.model.search_service_level_objective_attributes import SearchServiceLevelObjectiveAttributes
from datadog_api_client.v1.model.search_service_level_objective_data import SearchServiceLevelObjectiveData
from datadog_api_client.v1.model.series import Series
from datadog_api_client.v1.model.service_check import ServiceCheck
from datadog_api_client.v1.model.service_check_status import ServiceCheckStatus
from datadog_api_client.v1.model.service_checks import ServiceChecks
from datadog_api_client.v1.model.service_level_objective import ServiceLevelObjective
from datadog_api_client.v1.model.service_level_objective_query import ServiceLevelObjectiveQuery
from datadog_api_client.v1.model.service_level_objective_request import ServiceLevelObjectiveRequest
from datadog_api_client.v1.model.service_map_widget_definition import ServiceMapWidgetDefinition
from datadog_api_client.v1.model.service_map_widget_definition_type import ServiceMapWidgetDefinitionType
from datadog_api_client.v1.model.service_summary_widget_definition import ServiceSummaryWidgetDefinition
from datadog_api_client.v1.model.service_summary_widget_definition_type import ServiceSummaryWidgetDefinitionType
from datadog_api_client.v1.model.signal_archive_reason import SignalArchiveReason
from datadog_api_client.v1.model.signal_assignee_update_request import SignalAssigneeUpdateRequest
from datadog_api_client.v1.model.signal_state_update_request import SignalStateUpdateRequest
from datadog_api_client.v1.model.signal_triage_state import SignalTriageState
from datadog_api_client.v1.model.slack_integration_channel import SlackIntegrationChannel
from datadog_api_client.v1.model.slack_integration_channel_display import SlackIntegrationChannelDisplay
from datadog_api_client.v1.model.slack_integration_channels import SlackIntegrationChannels
from datadog_api_client.v1.model.successful_signal_update_response import SuccessfulSignalUpdateResponse
from datadog_api_client.v1.model.sunburst_widget_definition import SunburstWidgetDefinition
from datadog_api_client.v1.model.sunburst_widget_definition_type import SunburstWidgetDefinitionType
from datadog_api_client.v1.model.sunburst_widget_legend import SunburstWidgetLegend
from datadog_api_client.v1.model.sunburst_widget_legend_inline_automatic import SunburstWidgetLegendInlineAutomatic
from datadog_api_client.v1.model.sunburst_widget_legend_inline_automatic_type import (
    SunburstWidgetLegendInlineAutomaticType,
)
from datadog_api_client.v1.model.sunburst_widget_legend_table import SunburstWidgetLegendTable
from datadog_api_client.v1.model.sunburst_widget_legend_table_type import SunburstWidgetLegendTableType
from datadog_api_client.v1.model.sunburst_widget_request import SunburstWidgetRequest
from datadog_api_client.v1.model.synthetics_api_step import SyntheticsAPIStep
from datadog_api_client.v1.model.synthetics_api_step_subtype import SyntheticsAPIStepSubtype
from datadog_api_client.v1.model.synthetics_api_test import SyntheticsAPITest
from datadog_api_client.v1.model.synthetics_api_test_config import SyntheticsAPITestConfig
from datadog_api_client.v1.model.synthetics_api_test_result_data import SyntheticsAPITestResultData
from datadog_api_client.v1.model.synthetics_api_test_result_full import SyntheticsAPITestResultFull
from datadog_api_client.v1.model.synthetics_api_test_result_full_check import SyntheticsAPITestResultFullCheck
from datadog_api_client.v1.model.synthetics_api_test_result_short import SyntheticsAPITestResultShort
from datadog_api_client.v1.model.synthetics_api_test_result_short_result import SyntheticsAPITestResultShortResult
from datadog_api_client.v1.model.synthetics_api_test_type import SyntheticsAPITestType
from datadog_api_client.v1.model.synthetics_api_test_failure_code import SyntheticsApiTestFailureCode
from datadog_api_client.v1.model.synthetics_api_test_result_failure import SyntheticsApiTestResultFailure
from datadog_api_client.v1.model.synthetics_assertion import SyntheticsAssertion
from datadog_api_client.v1.model.synthetics_assertion_json_path_operator import SyntheticsAssertionJSONPathOperator
from datadog_api_client.v1.model.synthetics_assertion_json_path_target import SyntheticsAssertionJSONPathTarget
from datadog_api_client.v1.model.synthetics_assertion_json_path_target_target import (
    SyntheticsAssertionJSONPathTargetTarget,
)
from datadog_api_client.v1.model.synthetics_assertion_operator import SyntheticsAssertionOperator
from datadog_api_client.v1.model.synthetics_assertion_target import SyntheticsAssertionTarget
from datadog_api_client.v1.model.synthetics_assertion_type import SyntheticsAssertionType
from datadog_api_client.v1.model.synthetics_assertion_x_path_operator import SyntheticsAssertionXPathOperator
from datadog_api_client.v1.model.synthetics_assertion_x_path_target import SyntheticsAssertionXPathTarget
from datadog_api_client.v1.model.synthetics_assertion_x_path_target_target import SyntheticsAssertionXPathTargetTarget
from datadog_api_client.v1.model.synthetics_basic_auth import SyntheticsBasicAuth
from datadog_api_client.v1.model.synthetics_basic_auth_digest import SyntheticsBasicAuthDigest
from datadog_api_client.v1.model.synthetics_basic_auth_digest_type import SyntheticsBasicAuthDigestType
from datadog_api_client.v1.model.synthetics_basic_auth_ntlm import SyntheticsBasicAuthNTLM
from datadog_api_client.v1.model.synthetics_basic_auth_ntlm_type import SyntheticsBasicAuthNTLMType
from datadog_api_client.v1.model.synthetics_basic_auth_oauth_client import SyntheticsBasicAuthOauthClient
from datadog_api_client.v1.model.synthetics_basic_auth_oauth_client_type import SyntheticsBasicAuthOauthClientType
from datadog_api_client.v1.model.synthetics_basic_auth_oauth_rop import SyntheticsBasicAuthOauthROP
from datadog_api_client.v1.model.synthetics_basic_auth_oauth_rop_type import SyntheticsBasicAuthOauthROPType
from datadog_api_client.v1.model.synthetics_basic_auth_oauth_token_api_authentication import (
    SyntheticsBasicAuthOauthTokenApiAuthentication,
)
from datadog_api_client.v1.model.synthetics_basic_auth_sigv4 import SyntheticsBasicAuthSigv4
from datadog_api_client.v1.model.synthetics_basic_auth_sigv4_type import SyntheticsBasicAuthSigv4Type
from datadog_api_client.v1.model.synthetics_basic_auth_web import SyntheticsBasicAuthWeb
from datadog_api_client.v1.model.synthetics_basic_auth_web_type import SyntheticsBasicAuthWebType
from datadog_api_client.v1.model.synthetics_batch_details import SyntheticsBatchDetails
from datadog_api_client.v1.model.synthetics_batch_details_data import SyntheticsBatchDetailsData
from datadog_api_client.v1.model.synthetics_batch_result import SyntheticsBatchResult
from datadog_api_client.v1.model.synthetics_browser_error import SyntheticsBrowserError
from datadog_api_client.v1.model.synthetics_browser_error_type import SyntheticsBrowserErrorType
from datadog_api_client.v1.model.synthetics_browser_test import SyntheticsBrowserTest
from datadog_api_client.v1.model.synthetics_browser_test_config import SyntheticsBrowserTestConfig
from datadog_api_client.v1.model.synthetics_browser_test_failure_code import SyntheticsBrowserTestFailureCode
from datadog_api_client.v1.model.synthetics_browser_test_result_data import SyntheticsBrowserTestResultData
from datadog_api_client.v1.model.synthetics_browser_test_result_failure import SyntheticsBrowserTestResultFailure
from datadog_api_client.v1.model.synthetics_browser_test_result_full import SyntheticsBrowserTestResultFull
from datadog_api_client.v1.model.synthetics_browser_test_result_full_check import SyntheticsBrowserTestResultFullCheck
from datadog_api_client.v1.model.synthetics_browser_test_result_short import SyntheticsBrowserTestResultShort
from datadog_api_client.v1.model.synthetics_browser_test_result_short_result import (
    SyntheticsBrowserTestResultShortResult,
)
from datadog_api_client.v1.model.synthetics_browser_test_rum_settings import SyntheticsBrowserTestRumSettings
from datadog_api_client.v1.model.synthetics_browser_test_type import SyntheticsBrowserTestType
from datadog_api_client.v1.model.synthetics_browser_variable import SyntheticsBrowserVariable
from datadog_api_client.v1.model.synthetics_browser_variable_type import SyntheticsBrowserVariableType
from datadog_api_client.v1.model.synthetics_ci_batch_metadata import SyntheticsCIBatchMetadata
from datadog_api_client.v1.model.synthetics_ci_batch_metadata_ci import SyntheticsCIBatchMetadataCI
from datadog_api_client.v1.model.synthetics_ci_batch_metadata_git import SyntheticsCIBatchMetadataGit
from datadog_api_client.v1.model.synthetics_ci_batch_metadata_pipeline import SyntheticsCIBatchMetadataPipeline
from datadog_api_client.v1.model.synthetics_ci_batch_metadata_provider import SyntheticsCIBatchMetadataProvider
from datadog_api_client.v1.model.synthetics_ci_test import SyntheticsCITest
from datadog_api_client.v1.model.synthetics_ci_test_body import SyntheticsCITestBody
from datadog_api_client.v1.model.synthetics_check_type import SyntheticsCheckType
from datadog_api_client.v1.model.synthetics_config_variable import SyntheticsConfigVariable
from datadog_api_client.v1.model.synthetics_config_variable_type import SyntheticsConfigVariableType
from datadog_api_client.v1.model.synthetics_core_web_vitals import SyntheticsCoreWebVitals
from datadog_api_client.v1.model.synthetics_delete_tests_payload import SyntheticsDeleteTestsPayload
from datadog_api_client.v1.model.synthetics_delete_tests_response import SyntheticsDeleteTestsResponse
from datadog_api_client.v1.model.synthetics_deleted_test import SyntheticsDeletedTest
from datadog_api_client.v1.model.synthetics_device import SyntheticsDevice
from datadog_api_client.v1.model.synthetics_device_id import SyntheticsDeviceID
from datadog_api_client.v1.model.synthetics_get_api_test_latest_results_response import (
    SyntheticsGetAPITestLatestResultsResponse,
)
from datadog_api_client.v1.model.synthetics_get_browser_test_latest_results_response import (
    SyntheticsGetBrowserTestLatestResultsResponse,
)
from datadog_api_client.v1.model.synthetics_global_variable import SyntheticsGlobalVariable
from datadog_api_client.v1.model.synthetics_global_variable_attributes import SyntheticsGlobalVariableAttributes
from datadog_api_client.v1.model.synthetics_global_variable_parse_test_options import (
    SyntheticsGlobalVariableParseTestOptions,
)
from datadog_api_client.v1.model.synthetics_global_variable_parse_test_options_type import (
    SyntheticsGlobalVariableParseTestOptionsType,
)
from datadog_api_client.v1.model.synthetics_global_variable_parser_type import SyntheticsGlobalVariableParserType
from datadog_api_client.v1.model.synthetics_global_variable_value import SyntheticsGlobalVariableValue
from datadog_api_client.v1.model.synthetics_list_global_variables_response import SyntheticsListGlobalVariablesResponse
from datadog_api_client.v1.model.synthetics_list_tests_response import SyntheticsListTestsResponse
from datadog_api_client.v1.model.synthetics_location import SyntheticsLocation
from datadog_api_client.v1.model.synthetics_locations import SyntheticsLocations
from datadog_api_client.v1.model.synthetics_parsing_options import SyntheticsParsingOptions
from datadog_api_client.v1.model.synthetics_playing_tab import SyntheticsPlayingTab
from datadog_api_client.v1.model.synthetics_private_location import SyntheticsPrivateLocation
from datadog_api_client.v1.model.synthetics_private_location_creation_response import (
    SyntheticsPrivateLocationCreationResponse,
)
from datadog_api_client.v1.model.synthetics_private_location_creation_response_result_encryption import (
    SyntheticsPrivateLocationCreationResponseResultEncryption,
)
from datadog_api_client.v1.model.synthetics_private_location_metadata import SyntheticsPrivateLocationMetadata
from datadog_api_client.v1.model.synthetics_private_location_secrets import SyntheticsPrivateLocationSecrets
from datadog_api_client.v1.model.synthetics_private_location_secrets_authentication import (
    SyntheticsPrivateLocationSecretsAuthentication,
)
from datadog_api_client.v1.model.synthetics_private_location_secrets_config_decryption import (
    SyntheticsPrivateLocationSecretsConfigDecryption,
)
from datadog_api_client.v1.model.synthetics_restricted_roles import SyntheticsRestrictedRoles
from datadog_api_client.v1.model.synthetics_ssl_certificate import SyntheticsSSLCertificate
from datadog_api_client.v1.model.synthetics_ssl_certificate_issuer import SyntheticsSSLCertificateIssuer
from datadog_api_client.v1.model.synthetics_ssl_certificate_subject import SyntheticsSSLCertificateSubject
from datadog_api_client.v1.model.synthetics_status import SyntheticsStatus
from datadog_api_client.v1.model.synthetics_step import SyntheticsStep
from datadog_api_client.v1.model.synthetics_step_detail import SyntheticsStepDetail
from datadog_api_client.v1.model.synthetics_step_detail_warning import SyntheticsStepDetailWarning
from datadog_api_client.v1.model.synthetics_step_type import SyntheticsStepType
from datadog_api_client.v1.model.synthetics_test_call_type import SyntheticsTestCallType
from datadog_api_client.v1.model.synthetics_test_ci_options import SyntheticsTestCiOptions
from datadog_api_client.v1.model.synthetics_test_config import SyntheticsTestConfig
from datadog_api_client.v1.model.synthetics_test_details import SyntheticsTestDetails
from datadog_api_client.v1.model.synthetics_test_details_sub_type import SyntheticsTestDetailsSubType
from datadog_api_client.v1.model.synthetics_test_details_type import SyntheticsTestDetailsType
from datadog_api_client.v1.model.synthetics_test_execution_rule import SyntheticsTestExecutionRule
from datadog_api_client.v1.model.synthetics_test_headers import SyntheticsTestHeaders
from datadog_api_client.v1.model.synthetics_test_metadata import SyntheticsTestMetadata
from datadog_api_client.v1.model.synthetics_test_monitor_status import SyntheticsTestMonitorStatus
from datadog_api_client.v1.model.synthetics_test_options import SyntheticsTestOptions
from datadog_api_client.v1.model.synthetics_test_options_monitor_options import SyntheticsTestOptionsMonitorOptions
from datadog_api_client.v1.model.synthetics_test_options_retry import SyntheticsTestOptionsRetry
from datadog_api_client.v1.model.synthetics_test_pause_status import SyntheticsTestPauseStatus
from datadog_api_client.v1.model.synthetics_test_process_status import SyntheticsTestProcessStatus
from datadog_api_client.v1.model.synthetics_test_request import SyntheticsTestRequest
from datadog_api_client.v1.model.synthetics_test_request_body_type import SyntheticsTestRequestBodyType
from datadog_api_client.v1.model.synthetics_test_request_certificate import SyntheticsTestRequestCertificate
from datadog_api_client.v1.model.synthetics_test_request_certificate_item import SyntheticsTestRequestCertificateItem
from datadog_api_client.v1.model.synthetics_test_request_proxy import SyntheticsTestRequestProxy
from datadog_api_client.v1.model.synthetics_timing import SyntheticsTiming
from datadog_api_client.v1.model.synthetics_trigger_body import SyntheticsTriggerBody
from datadog_api_client.v1.model.synthetics_trigger_ci_test_location import SyntheticsTriggerCITestLocation
from datadog_api_client.v1.model.synthetics_trigger_ci_test_run_result import SyntheticsTriggerCITestRunResult
from datadog_api_client.v1.model.synthetics_trigger_ci_tests_response import SyntheticsTriggerCITestsResponse
from datadog_api_client.v1.model.synthetics_trigger_test import SyntheticsTriggerTest
from datadog_api_client.v1.model.synthetics_update_test_pause_status_payload import (
    SyntheticsUpdateTestPauseStatusPayload,
)
from datadog_api_client.v1.model.synthetics_variable_parser import SyntheticsVariableParser
from datadog_api_client.v1.model.synthetics_warning_type import SyntheticsWarningType
from datadog_api_client.v1.model.table_widget_cell_display_mode import TableWidgetCellDisplayMode
from datadog_api_client.v1.model.table_widget_definition import TableWidgetDefinition
from datadog_api_client.v1.model.table_widget_definition_type import TableWidgetDefinitionType
from datadog_api_client.v1.model.table_widget_has_search_bar import TableWidgetHasSearchBar
from datadog_api_client.v1.model.table_widget_request import TableWidgetRequest
from datadog_api_client.v1.model.tag_to_hosts import TagToHosts
from datadog_api_client.v1.model.target_format_type import TargetFormatType
from datadog_api_client.v1.model.timeseries_background import TimeseriesBackground
from datadog_api_client.v1.model.timeseries_background_type import TimeseriesBackgroundType
from datadog_api_client.v1.model.timeseries_widget_definition import TimeseriesWidgetDefinition
from datadog_api_client.v1.model.timeseries_widget_definition_type import TimeseriesWidgetDefinitionType
from datadog_api_client.v1.model.timeseries_widget_expression_alias import TimeseriesWidgetExpressionAlias
from datadog_api_client.v1.model.timeseries_widget_legend_column import TimeseriesWidgetLegendColumn
from datadog_api_client.v1.model.timeseries_widget_legend_layout import TimeseriesWidgetLegendLayout
from datadog_api_client.v1.model.timeseries_widget_request import TimeseriesWidgetRequest
from datadog_api_client.v1.model.toplist_widget_definition import ToplistWidgetDefinition
from datadog_api_client.v1.model.toplist_widget_definition_type import ToplistWidgetDefinitionType
from datadog_api_client.v1.model.toplist_widget_request import ToplistWidgetRequest
from datadog_api_client.v1.model.topology_map_widget_definition import TopologyMapWidgetDefinition
from datadog_api_client.v1.model.topology_map_widget_definition_type import TopologyMapWidgetDefinitionType
from datadog_api_client.v1.model.topology_query import TopologyQuery
from datadog_api_client.v1.model.topology_query_data_source import TopologyQueryDataSource
from datadog_api_client.v1.model.topology_request import TopologyRequest
from datadog_api_client.v1.model.topology_request_type import TopologyRequestType
from datadog_api_client.v1.model.tree_map_color_by import TreeMapColorBy
from datadog_api_client.v1.model.tree_map_group_by import TreeMapGroupBy
from datadog_api_client.v1.model.tree_map_size_by import TreeMapSizeBy
from datadog_api_client.v1.model.tree_map_widget_definition import TreeMapWidgetDefinition
from datadog_api_client.v1.model.tree_map_widget_definition_type import TreeMapWidgetDefinitionType
from datadog_api_client.v1.model.tree_map_widget_request import TreeMapWidgetRequest
from datadog_api_client.v1.model.usage_analyzed_logs_hour import UsageAnalyzedLogsHour
from datadog_api_client.v1.model.usage_analyzed_logs_response import UsageAnalyzedLogsResponse
from datadog_api_client.v1.model.usage_attribution_aggregates import UsageAttributionAggregates
from datadog_api_client.v1.model.usage_attribution_aggregates_body import UsageAttributionAggregatesBody
from datadog_api_client.v1.model.usage_attribution_body import UsageAttributionBody
from datadog_api_client.v1.model.usage_attribution_metadata import UsageAttributionMetadata
from datadog_api_client.v1.model.usage_attribution_pagination import UsageAttributionPagination
from datadog_api_client.v1.model.usage_attribution_response import UsageAttributionResponse
from datadog_api_client.v1.model.usage_attribution_sort import UsageAttributionSort
from datadog_api_client.v1.model.usage_attribution_supported_metrics import UsageAttributionSupportedMetrics
from datadog_api_client.v1.model.usage_attribution_tag_names import UsageAttributionTagNames
from datadog_api_client.v1.model.usage_attribution_values import UsageAttributionValues
from datadog_api_client.v1.model.usage_audit_logs_hour import UsageAuditLogsHour
from datadog_api_client.v1.model.usage_audit_logs_response import UsageAuditLogsResponse
from datadog_api_client.v1.model.usage_billable_summary_body import UsageBillableSummaryBody
from datadog_api_client.v1.model.usage_billable_summary_hour import UsageBillableSummaryHour
from datadog_api_client.v1.model.usage_billable_summary_keys import UsageBillableSummaryKeys
from datadog_api_client.v1.model.usage_billable_summary_response import UsageBillableSummaryResponse
from datadog_api_client.v1.model.usage_ci_visibility_hour import UsageCIVisibilityHour
from datadog_api_client.v1.model.usage_ci_visibility_response import UsageCIVisibilityResponse
from datadog_api_client.v1.model.usage_cws_hour import UsageCWSHour
from datadog_api_client.v1.model.usage_cws_response import UsageCWSResponse
from datadog_api_client.v1.model.usage_cloud_security_posture_management_hour import (
    UsageCloudSecurityPostureManagementHour,
)
from datadog_api_client.v1.model.usage_cloud_security_posture_management_response import (
    UsageCloudSecurityPostureManagementResponse,
)
from datadog_api_client.v1.model.usage_custom_reports_attributes import UsageCustomReportsAttributes
from datadog_api_client.v1.model.usage_custom_reports_data import UsageCustomReportsData
from datadog_api_client.v1.model.usage_custom_reports_meta import UsageCustomReportsMeta
from datadog_api_client.v1.model.usage_custom_reports_page import UsageCustomReportsPage
from datadog_api_client.v1.model.usage_custom_reports_response import UsageCustomReportsResponse
from datadog_api_client.v1.model.usage_dbm_hour import UsageDBMHour
from datadog_api_client.v1.model.usage_dbm_response import UsageDBMResponse
from datadog_api_client.v1.model.usage_fargate_hour import UsageFargateHour
from datadog_api_client.v1.model.usage_fargate_response import UsageFargateResponse
from datadog_api_client.v1.model.usage_host_hour import UsageHostHour
from datadog_api_client.v1.model.usage_hosts_response import UsageHostsResponse
from datadog_api_client.v1.model.usage_incident_management_hour import UsageIncidentManagementHour
from datadog_api_client.v1.model.usage_incident_management_response import UsageIncidentManagementResponse
from datadog_api_client.v1.model.usage_indexed_spans_hour import UsageIndexedSpansHour
from datadog_api_client.v1.model.usage_indexed_spans_response import UsageIndexedSpansResponse
from datadog_api_client.v1.model.usage_ingested_spans_hour import UsageIngestedSpansHour
from datadog_api_client.v1.model.usage_ingested_spans_response import UsageIngestedSpansResponse
from datadog_api_client.v1.model.usage_iot_hour import UsageIoTHour
from datadog_api_client.v1.model.usage_iot_response import UsageIoTResponse
from datadog_api_client.v1.model.usage_lambda_hour import UsageLambdaHour
from datadog_api_client.v1.model.usage_lambda_response import UsageLambdaResponse
from datadog_api_client.v1.model.usage_logs_by_index_hour import UsageLogsByIndexHour
from datadog_api_client.v1.model.usage_logs_by_index_response import UsageLogsByIndexResponse
from datadog_api_client.v1.model.usage_logs_by_retention_hour import UsageLogsByRetentionHour
from datadog_api_client.v1.model.usage_logs_by_retention_response import UsageLogsByRetentionResponse
from datadog_api_client.v1.model.usage_logs_hour import UsageLogsHour
from datadog_api_client.v1.model.usage_logs_response import UsageLogsResponse
from datadog_api_client.v1.model.usage_metric_category import UsageMetricCategory
from datadog_api_client.v1.model.usage_network_flows_hour import UsageNetworkFlowsHour
from datadog_api_client.v1.model.usage_network_flows_response import UsageNetworkFlowsResponse
from datadog_api_client.v1.model.usage_network_hosts_hour import UsageNetworkHostsHour
from datadog_api_client.v1.model.usage_network_hosts_response import UsageNetworkHostsResponse
from datadog_api_client.v1.model.usage_online_archive_hour import UsageOnlineArchiveHour
from datadog_api_client.v1.model.usage_online_archive_response import UsageOnlineArchiveResponse
from datadog_api_client.v1.model.usage_profiling_hour import UsageProfilingHour
from datadog_api_client.v1.model.usage_profiling_response import UsageProfilingResponse
from datadog_api_client.v1.model.usage_reports_type import UsageReportsType
from datadog_api_client.v1.model.usage_rum_sessions_hour import UsageRumSessionsHour
from datadog_api_client.v1.model.usage_rum_sessions_response import UsageRumSessionsResponse
from datadog_api_client.v1.model.usage_rum_units_hour import UsageRumUnitsHour
from datadog_api_client.v1.model.usage_rum_units_response import UsageRumUnitsResponse
from datadog_api_client.v1.model.usage_sds_hour import UsageSDSHour
from datadog_api_client.v1.model.usage_sds_response import UsageSDSResponse
from datadog_api_client.v1.model.usage_snmp_hour import UsageSNMPHour
from datadog_api_client.v1.model.usage_snmp_response import UsageSNMPResponse
from datadog_api_client.v1.model.usage_sort import UsageSort
from datadog_api_client.v1.model.usage_sort_direction import UsageSortDirection
from datadog_api_client.v1.model.usage_specified_custom_reports_attributes import UsageSpecifiedCustomReportsAttributes
from datadog_api_client.v1.model.usage_specified_custom_reports_data import UsageSpecifiedCustomReportsData
from datadog_api_client.v1.model.usage_specified_custom_reports_meta import UsageSpecifiedCustomReportsMeta
from datadog_api_client.v1.model.usage_specified_custom_reports_page import UsageSpecifiedCustomReportsPage
from datadog_api_client.v1.model.usage_specified_custom_reports_response import UsageSpecifiedCustomReportsResponse
from datadog_api_client.v1.model.usage_summary_date import UsageSummaryDate
from datadog_api_client.v1.model.usage_summary_date_org import UsageSummaryDateOrg
from datadog_api_client.v1.model.usage_summary_response import UsageSummaryResponse
from datadog_api_client.v1.model.usage_synthetics_api_hour import UsageSyntheticsAPIHour
from datadog_api_client.v1.model.usage_synthetics_api_response import UsageSyntheticsAPIResponse
from datadog_api_client.v1.model.usage_synthetics_browser_hour import UsageSyntheticsBrowserHour
from datadog_api_client.v1.model.usage_synthetics_browser_response import UsageSyntheticsBrowserResponse
from datadog_api_client.v1.model.usage_synthetics_hour import UsageSyntheticsHour
from datadog_api_client.v1.model.usage_synthetics_response import UsageSyntheticsResponse
from datadog_api_client.v1.model.usage_timeseries_hour import UsageTimeseriesHour
from datadog_api_client.v1.model.usage_timeseries_response import UsageTimeseriesResponse
from datadog_api_client.v1.model.usage_top_avg_metrics_hour import UsageTopAvgMetricsHour
from datadog_api_client.v1.model.usage_top_avg_metrics_metadata import UsageTopAvgMetricsMetadata
from datadog_api_client.v1.model.usage_top_avg_metrics_pagination import UsageTopAvgMetricsPagination
from datadog_api_client.v1.model.usage_top_avg_metrics_response import UsageTopAvgMetricsResponse
from datadog_api_client.v1.model.user import User
from datadog_api_client.v1.model.user_disable_response import UserDisableResponse
from datadog_api_client.v1.model.user_list_response import UserListResponse
from datadog_api_client.v1.model.user_response import UserResponse
from datadog_api_client.v1.model.webhooks_integration import WebhooksIntegration
from datadog_api_client.v1.model.webhooks_integration_custom_variable import WebhooksIntegrationCustomVariable
from datadog_api_client.v1.model.webhooks_integration_custom_variable_response import (
    WebhooksIntegrationCustomVariableResponse,
)
from datadog_api_client.v1.model.webhooks_integration_custom_variable_update_request import (
    WebhooksIntegrationCustomVariableUpdateRequest,
)
from datadog_api_client.v1.model.webhooks_integration_encoding import WebhooksIntegrationEncoding
from datadog_api_client.v1.model.webhooks_integration_update_request import WebhooksIntegrationUpdateRequest
from datadog_api_client.v1.model.widget import Widget
from datadog_api_client.v1.model.widget_aggregator import WidgetAggregator
from datadog_api_client.v1.model.widget_axis import WidgetAxis
from datadog_api_client.v1.model.widget_change_type import WidgetChangeType
from datadog_api_client.v1.model.widget_color_preference import WidgetColorPreference
from datadog_api_client.v1.model.widget_comparator import WidgetComparator
from datadog_api_client.v1.model.widget_compare_to import WidgetCompareTo
from datadog_api_client.v1.model.widget_conditional_format import WidgetConditionalFormat
from datadog_api_client.v1.model.widget_custom_link import WidgetCustomLink
from datadog_api_client.v1.model.widget_definition import WidgetDefinition
from datadog_api_client.v1.model.widget_display_type import WidgetDisplayType
from datadog_api_client.v1.model.widget_event import WidgetEvent
from datadog_api_client.v1.model.widget_event_size import WidgetEventSize
from datadog_api_client.v1.model.widget_field_sort import WidgetFieldSort
from datadog_api_client.v1.model.widget_formula import WidgetFormula
from datadog_api_client.v1.model.widget_formula_limit import WidgetFormulaLimit
from datadog_api_client.v1.model.widget_formula_style import WidgetFormulaStyle
from datadog_api_client.v1.model.widget_grouping import WidgetGrouping
from datadog_api_client.v1.model.widget_horizontal_align import WidgetHorizontalAlign
from datadog_api_client.v1.model.widget_image_sizing import WidgetImageSizing
from datadog_api_client.v1.model.widget_layout import WidgetLayout
from datadog_api_client.v1.model.widget_layout_type import WidgetLayoutType
from datadog_api_client.v1.model.widget_line_type import WidgetLineType
from datadog_api_client.v1.model.widget_line_width import WidgetLineWidth
from datadog_api_client.v1.model.widget_live_span import WidgetLiveSpan
from datadog_api_client.v1.model.widget_margin import WidgetMargin
from datadog_api_client.v1.model.widget_marker import WidgetMarker
from datadog_api_client.v1.model.widget_message_display import WidgetMessageDisplay
from datadog_api_client.v1.model.widget_monitor_summary_display_format import WidgetMonitorSummaryDisplayFormat
from datadog_api_client.v1.model.widget_monitor_summary_sort import WidgetMonitorSummarySort
from datadog_api_client.v1.model.widget_node_type import WidgetNodeType
from datadog_api_client.v1.model.widget_order_by import WidgetOrderBy
from datadog_api_client.v1.model.widget_palette import WidgetPalette
from datadog_api_client.v1.model.widget_request_style import WidgetRequestStyle
from datadog_api_client.v1.model.widget_service_summary_display_format import WidgetServiceSummaryDisplayFormat
from datadog_api_client.v1.model.widget_size_format import WidgetSizeFormat
from datadog_api_client.v1.model.widget_sort import WidgetSort
from datadog_api_client.v1.model.widget_style import WidgetStyle
from datadog_api_client.v1.model.widget_summary_type import WidgetSummaryType
from datadog_api_client.v1.model.widget_text_align import WidgetTextAlign
from datadog_api_client.v1.model.widget_tick_edge import WidgetTickEdge
from datadog_api_client.v1.model.widget_time import WidgetTime
from datadog_api_client.v1.model.widget_time_windows import WidgetTimeWindows
from datadog_api_client.v1.model.widget_vertical_align import WidgetVerticalAlign
from datadog_api_client.v1.model.widget_view_mode import WidgetViewMode
from datadog_api_client.v1.model.widget_viz_type import WidgetVizType



"""
Take graph snapshots returns "OK" response
"""

from datetime import datetime
from dateutil.relativedelta import relativedelta
from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v1.api.snapshots_api import SnapshotsApi

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = SnapshotsApi(api_client)
    response = api_instance.get_graph_snapshot(
        metric_query="avg:system.load.1{*}",
        start=int((datetime.now() + relativedelta(days=-1)).timestamp()),
        end=int(datetime.now().timestamp()),
        title="System load",
        height=400,
        width=600,
    )

    print(response)



"""
Get a cloud configuration rule's details returns "OK" response
"""

from os import environ
from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v2.api.security_monitoring_api import SecurityMonitoringApi

# there is a valid "cloud_configuration_rule" in the system
CLOUD_CONFIGURATION_RULE_ID = environ["CLOUD_CONFIGURATION_RULE_ID"]

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = SecurityMonitoringApi(api_client)
    response = api_instance.get_security_monitoring_rule(
        rule_id=CLOUD_CONFIGURATION_RULE_ID,
    )

    print(response)



"""
Create a new dashboard with a query value widget using timeseries background
"""

from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v1.api.dashboards_api import DashboardsApi
from datadog_api_client.v1.model.dashboard import Dashboard
from datadog_api_client.v1.model.dashboard_layout_type import DashboardLayoutType
from datadog_api_client.v1.model.formula_and_function_metric_aggregation import FormulaAndFunctionMetricAggregation
from datadog_api_client.v1.model.formula_and_function_metric_data_source import FormulaAndFunctionMetricDataSource
from datadog_api_client.v1.model.formula_and_function_metric_query_definition import (
    FormulaAndFunctionMetricQueryDefinition,
)
from datadog_api_client.v1.model.formula_and_function_response_format import FormulaAndFunctionResponseFormat
from datadog_api_client.v1.model.query_value_widget_definition import QueryValueWidgetDefinition
from datadog_api_client.v1.model.query_value_widget_definition_type import QueryValueWidgetDefinitionType
from datadog_api_client.v1.model.query_value_widget_request import QueryValueWidgetRequest
from datadog_api_client.v1.model.timeseries_background import TimeseriesBackground
from datadog_api_client.v1.model.timeseries_background_type import TimeseriesBackgroundType
from datadog_api_client.v1.model.widget import Widget
from datadog_api_client.v1.model.widget_axis import WidgetAxis
from datadog_api_client.v1.model.widget_formula import WidgetFormula
from datadog_api_client.v1.model.widget_layout import WidgetLayout
from datadog_api_client.v1.model.widget_text_align import WidgetTextAlign
from datadog_api_client.v1.model.widget_time import WidgetTime

body = Dashboard(
    layout_type=DashboardLayoutType.ORDERED,
    title="Example-Create_a_new_dashboard_with_a_query_value_widget_using_timeseries_background with QVW Timeseries Background",
    widgets=[
        Widget(
            definition=QueryValueWidgetDefinition(
                title_size="16",
                title="",
                title_align=WidgetTextAlign.LEFT,
                precision=2,
                time=WidgetTime(),
                autoscale=True,
                requests=[
                    QueryValueWidgetRequest(
                        formulas=[
                            WidgetFormula(
                                formula="query1",
                            ),
                        ],
                        response_format=FormulaAndFunctionResponseFormat.SCALAR,
                        queries=[
                            FormulaAndFunctionMetricQueryDefinition(
                                query="sum:my.cool.count.metric{*}",
                                data_source=FormulaAndFunctionMetricDataSource.METRICS,
                                name="query1",
                                aggregator=FormulaAndFunctionMetricAggregation.PERCENTILE,
                            ),
                        ],
                    ),
                ],
                type=QueryValueWidgetDefinitionType.QUERY_VALUE,
                timeseries_background=TimeseriesBackground(
                    type=TimeseriesBackgroundType.AREA,
                    yaxis=WidgetAxis(
                        include_zero=True,
                    ),
                ),
            ),
            layout=WidgetLayout(
                y=0,
                x=0,
                height=2,
                width=2,
            ),
        ),
    ],
)

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = DashboardsApi(api_client)
    response = api_instance.create_dashboard(body=body)

    print(response)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import List, Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.slo_history_metrics_series import SLOHistoryMetricsSeries


class SLOHistoryMetrics(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.slo_history_metrics_series import SLOHistoryMetricsSeries

        return {
            "denominator": (SLOHistoryMetricsSeries,),
            "interval": (int,),
            "message": (str,),
            "numerator": (SLOHistoryMetricsSeries,),
            "query": (str,),
            "res_type": (str,),
            "resp_version": (int,),
            "times": ([float],),
        }

    attribute_map = {
        "denominator": "denominator",
        "interval": "interval",
        "message": "message",
        "numerator": "numerator",
        "query": "query",
        "res_type": "res_type",
        "resp_version": "resp_version",
        "times": "times",
    }

    def __init__(
        self_,
        denominator: SLOHistoryMetricsSeries,
        interval: int,
        numerator: SLOHistoryMetricsSeries,
        query: str,
        res_type: str,
        resp_version: int,
        times: List[float],
        message: Union[str, UnsetType] = unset,
        **kwargs,
    ):
        """
        A ``metric`` based SLO history response.

        This is not included in responses for ``monitor`` based SLOs.

        :param denominator: A representation of ``metric`` based SLO time series for the provided queries.
            This is the same response type from ``batch_query`` endpoint.
        :type denominator: SLOHistoryMetricsSeries

        :param interval: The aggregated query interval for the series data. It's implicit based on the query time window.
        :type interval: int

        :param message: Optional message if there are specific query issues/warnings.
        :type message: str, optional

        :param numerator: A representation of ``metric`` based SLO time series for the provided queries.
            This is the same response type from ``batch_query`` endpoint.
        :type numerator: SLOHistoryMetricsSeries

        :param query: The combined numerator and denominator query CSV.
        :type query: str

        :param res_type: The series result type. This mimics ``batch_query`` response type.
        :type res_type: str

        :param resp_version: The series response version type. This mimics ``batch_query`` response type.
        :type resp_version: int

        :param times: An array of query timestamps in EPOCH milliseconds.
        :type times: [float]
        """
        if message is not unset:
            kwargs["message"] = message
        super().__init__(kwargs)

        self_.denominator = denominator
        self_.interval = interval
        self_.numerator = numerator
        self_.query = query
        self_.res_type = res_type
        self_.resp_version = resp_version
        self_.times = times



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Dict, List, Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.host_meta import HostMeta
    from datadog_api_client.v1.model.host_metrics import HostMetrics


class Host(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.host_meta import HostMeta
        from datadog_api_client.v1.model.host_metrics import HostMetrics

        return {
            "aliases": ([str],),
            "apps": ([str],),
            "aws_name": (str,),
            "host_name": (str,),
            "id": (int,),
            "is_muted": (bool,),
            "last_reported_time": (int,),
            "meta": (HostMeta,),
            "metrics": (HostMetrics,),
            "mute_timeout": (int,),
            "name": (str,),
            "sources": ([str],),
            "tags_by_source": ({str: ([str],)},),
            "up": (bool,),
        }

    attribute_map = {
        "aliases": "aliases",
        "apps": "apps",
        "aws_name": "aws_name",
        "host_name": "host_name",
        "id": "id",
        "is_muted": "is_muted",
        "last_reported_time": "last_reported_time",
        "meta": "meta",
        "metrics": "metrics",
        "mute_timeout": "mute_timeout",
        "name": "name",
        "sources": "sources",
        "tags_by_source": "tags_by_source",
        "up": "up",
    }

    def __init__(
        self_,
        aliases: Union[List[str], UnsetType] = unset,
        apps: Union[List[str], UnsetType] = unset,
        aws_name: Union[str, UnsetType] = unset,
        host_name: Union[str, UnsetType] = unset,
        id: Union[int, UnsetType] = unset,
        is_muted: Union[bool, UnsetType] = unset,
        last_reported_time: Union[int, UnsetType] = unset,
        meta: Union[HostMeta, UnsetType] = unset,
        metrics: Union[HostMetrics, UnsetType] = unset,
        mute_timeout: Union[int, UnsetType] = unset,
        name: Union[str, UnsetType] = unset,
        sources: Union[List[str], UnsetType] = unset,
        tags_by_source: Union[Dict[str, List[str]], UnsetType] = unset,
        up: Union[bool, UnsetType] = unset,
        **kwargs,
    ):
        """
        Object representing a host.

        :param aliases: Host aliases collected by Datadog.
        :type aliases: [str], optional

        :param apps: The Datadog integrations reporting metrics for the host.
        :type apps: [str], optional

        :param aws_name: AWS name of your host.
        :type aws_name: str, optional

        :param host_name: The host name.
        :type host_name: str, optional

        :param id: The host ID.
        :type id: int, optional

        :param is_muted: If a host is muted or unmuted.
        :type is_muted: bool, optional

        :param last_reported_time: Last time the host reported a metric data point.
        :type last_reported_time: int, optional

        :param meta: Metadata associated with your host.
        :type meta: HostMeta, optional

        :param metrics: Host Metrics collected.
        :type metrics: HostMetrics, optional

        :param mute_timeout: Timeout of the mute applied to your host.
        :type mute_timeout: int, optional

        :param name: The host name.
        :type name: str, optional

        :param sources: Source or cloud provider associated with your host.
        :type sources: [str], optional

        :param tags_by_source: List of tags for each source (AWS, Datadog Agent, Chef..).
        :type tags_by_source: {str: ([str],)}, optional

        :param up: Displays UP when the expected metrics are received and displays ``???`` if no metrics are received.
        :type up: bool, optional
        """
        if aliases is not unset:
            kwargs["aliases"] = aliases
        if apps is not unset:
            kwargs["apps"] = apps
        if aws_name is not unset:
            kwargs["aws_name"] = aws_name
        if host_name is not unset:
            kwargs["host_name"] = host_name
        if id is not unset:
            kwargs["id"] = id
        if is_muted is not unset:
            kwargs["is_muted"] = is_muted
        if last_reported_time is not unset:
            kwargs["last_reported_time"] = last_reported_time
        if meta is not unset:
            kwargs["meta"] = meta
        if metrics is not unset:
            kwargs["metrics"] = metrics
        if mute_timeout is not unset:
            kwargs["mute_timeout"] = mute_timeout
        if name is not unset:
            kwargs["name"] = name
        if sources is not unset:
            kwargs["sources"] = sources
        if tags_by_source is not unset:
            kwargs["tags_by_source"] = tags_by_source
        if up is not unset:
            kwargs["up"] = up
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.slack_integration_channel_display import SlackIntegrationChannelDisplay


class SlackIntegrationChannel(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.slack_integration_channel_display import SlackIntegrationChannelDisplay

        return {
            "display": (SlackIntegrationChannelDisplay,),
            "name": (str,),
        }

    attribute_map = {
        "display": "display",
        "name": "name",
    }

    def __init__(
        self_,
        display: Union[SlackIntegrationChannelDisplay, UnsetType] = unset,
        name: Union[str, UnsetType] = unset,
        **kwargs,
    ):
        """
        The Slack channel configuration.

        :param display: Configuration options for what is shown in an alert event message.
        :type display: SlackIntegrationChannelDisplay, optional

        :param name: Your channel name.
        :type name: str, optional
        """
        if display is not unset:
            kwargs["display"] = display
        if name is not unset:
            kwargs["name"] = name
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


class FullAPIKeyAttributes(ModelNormal):
    validations = {
        "last4": {
            "max_length": 4,
            "min_length": 4,
        },
    }

    @cached_property
    def openapi_types(_):
        return {
            "created_at": (str,),
            "key": (str,),
            "last4": (str,),
            "modified_at": (str,),
            "name": (str,),
        }

    attribute_map = {
        "created_at": "created_at",
        "key": "key",
        "last4": "last4",
        "modified_at": "modified_at",
        "name": "name",
    }
    read_only_vars = {
        "created_at",
        "key",
        "last4",
        "modified_at",
    }

    def __init__(
        self_,
        created_at: Union[str, UnsetType] = unset,
        key: Union[str, UnsetType] = unset,
        last4: Union[str, UnsetType] = unset,
        modified_at: Union[str, UnsetType] = unset,
        name: Union[str, UnsetType] = unset,
        **kwargs,
    ):
        """
        Attributes of a full API key.

        :param created_at: Creation date of the API key.
        :type created_at: str, optional

        :param key: The API key.
        :type key: str, optional

        :param last4: The last four characters of the API key.
        :type last4: str, optional

        :param modified_at: Date the API key was last modified.
        :type modified_at: str, optional

        :param name: Name of the API key.
        :type name: str, optional
        """
        if created_at is not unset:
            kwargs["created_at"] = created_at
        if key is not unset:
            kwargs["key"] = key
        if last4 is not unset:
            kwargs["last4"] = last4
        if modified_at is not unset:
            kwargs["modified_at"] = modified_at
        if name is not unset:
            kwargs["name"] = name
        super().__init__(kwargs)



"""
Create a new dashboard with trace_service widget
"""

from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v1.api.dashboards_api import DashboardsApi
from datadog_api_client.v1.model.dashboard import Dashboard
from datadog_api_client.v1.model.dashboard_layout_type import DashboardLayoutType
from datadog_api_client.v1.model.service_summary_widget_definition import ServiceSummaryWidgetDefinition
from datadog_api_client.v1.model.service_summary_widget_definition_type import ServiceSummaryWidgetDefinitionType
from datadog_api_client.v1.model.widget import Widget
from datadog_api_client.v1.model.widget_layout import WidgetLayout
from datadog_api_client.v1.model.widget_service_summary_display_format import WidgetServiceSummaryDisplayFormat
from datadog_api_client.v1.model.widget_size_format import WidgetSizeFormat
from datadog_api_client.v1.model.widget_time import WidgetTime

body = Dashboard(
    title="Example-Create_a_new_dashboard_with_trace_service_widget",
    description="",
    widgets=[
        Widget(
            layout=WidgetLayout(
                x=0,
                y=0,
                width=72,
                height=72,
            ),
            definition=ServiceSummaryWidgetDefinition(
                title="Service Summary",
                time=WidgetTime(),
                type=ServiceSummaryWidgetDefinitionType.TRACE_SERVICE,
                env="none",
                service="",
                span_name="",
                show_hits=True,
                show_errors=True,
                show_latency=True,
                show_breakdown=True,
                show_distribution=True,
                show_resource_list=False,
                size_format=WidgetSizeFormat.MEDIUM,
                display_format=WidgetServiceSummaryDisplayFormat.TWO_COLUMN,
            ),
        ),
    ],
    template_variables=[],
    layout_type=DashboardLayoutType.FREE,
    is_read_only=False,
    notify_list=[],
)

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = DashboardsApi(api_client)
    response = api_instance.create_dashboard(body=body)

    print(response)



"""
Create a new dashboard with manage_status widget
"""

from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v1.api.dashboards_api import DashboardsApi
from datadog_api_client.v1.model.dashboard import Dashboard
from datadog_api_client.v1.model.dashboard_layout_type import DashboardLayoutType
from datadog_api_client.v1.model.monitor_summary_widget_definition import MonitorSummaryWidgetDefinition
from datadog_api_client.v1.model.monitor_summary_widget_definition_type import MonitorSummaryWidgetDefinitionType
from datadog_api_client.v1.model.widget import Widget
from datadog_api_client.v1.model.widget_color_preference import WidgetColorPreference
from datadog_api_client.v1.model.widget_layout import WidgetLayout
from datadog_api_client.v1.model.widget_monitor_summary_display_format import WidgetMonitorSummaryDisplayFormat
from datadog_api_client.v1.model.widget_monitor_summary_sort import WidgetMonitorSummarySort
from datadog_api_client.v1.model.widget_summary_type import WidgetSummaryType

body = Dashboard(
    title="Example-Create_a_new_dashboard_with_manage_status_widget",
    description="",
    widgets=[
        Widget(
            layout=WidgetLayout(
                x=0,
                y=0,
                width=50,
                height=25,
            ),
            definition=MonitorSummaryWidgetDefinition(
                type=MonitorSummaryWidgetDefinitionType.MANAGE_STATUS,
                summary_type=WidgetSummaryType.MONITORS,
                display_format=WidgetMonitorSummaryDisplayFormat.COUNTS_AND_LIST,
                color_preference=WidgetColorPreference.TEXT,
                hide_zero_counts=True,
                show_last_triggered=False,
                query="",
                sort=WidgetMonitorSummarySort.STATUS_ASCENDING,
                count=50,
                start=0,
            ),
        ),
    ],
    template_variables=[],
    layout_type=DashboardLayoutType.FREE,
    is_read_only=False,
    notify_list=[],
)

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = DashboardsApi(api_client)
    response = api_instance.create_dashboard(body=body)

    print(response)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations


from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
)


class EventQueryDefinition(ModelNormal):
    @cached_property
    def openapi_types(_):
        return {
            "search": (str,),
            "tags_execution": (str,),
        }

    attribute_map = {
        "search": "search",
        "tags_execution": "tags_execution",
    }

    def __init__(self_, search: str, tags_execution: str, **kwargs):
        """
        The event query.

        :param search: The query being made on the event.
        :type search: str

        :param tags_execution: The execution method for multi-value filters. Can be either and or or.
        :type tags_execution: str
        """
        super().__init__(kwargs)

        self_.search = search
        self_.tags_execution = tags_execution



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.logs_sort import LogsSort
    from datadog_api_client.v1.model.logs_list_request_time import LogsListRequestTime


class LogsListRequest(ModelNormal):
    validations = {
        "limit": {
            "inclusive_maximum": 1000,
        },
    }

    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.logs_sort import LogsSort
        from datadog_api_client.v1.model.logs_list_request_time import LogsListRequestTime

        return {
            "index": (str,),
            "limit": (int,),
            "query": (str,),
            "sort": (LogsSort,),
            "start_at": (str,),
            "time": (LogsListRequestTime,),
        }

    attribute_map = {
        "index": "index",
        "limit": "limit",
        "query": "query",
        "sort": "sort",
        "start_at": "startAt",
        "time": "time",
    }

    def __init__(
        self_,
        time: LogsListRequestTime,
        index: Union[str, UnsetType] = unset,
        limit: Union[int, UnsetType] = unset,
        query: Union[str, UnsetType] = unset,
        sort: Union[LogsSort, UnsetType] = unset,
        start_at: Union[str, UnsetType] = unset,
        **kwargs,
    ):
        """
        Object to send with the request to retrieve a list of logs from your Organization.

        :param index: The log index on which the request is performed. For multi-index organizations,
            the default is all live indexes. Historical indexes of rehydrated logs must be specified.
        :type index: str, optional

        :param limit: Number of logs return in the response.
        :type limit: int, optional

        :param query: The search query - following the log search syntax.
        :type query: str, optional

        :param sort: Time-ascending ``asc`` or time-descending ``desc`` results.
        :type sort: LogsSort, optional

        :param start_at: Hash identifier of the first log to return in the list, available in a log ``id`` attribute.
            This parameter is used for the pagination feature.

            **Note** : This parameter is ignored if the corresponding log
            is out of the scope of the specified time window.
        :type start_at: str, optional

        :param time: Timeframe to retrieve the log from.
        :type time: LogsListRequestTime
        """
        if index is not unset:
            kwargs["index"] = index
        if limit is not unset:
            kwargs["limit"] = limit
        if query is not unset:
            kwargs["query"] = query
        if sort is not unset:
            kwargs["sort"] = sort
        if start_at is not unset:
            kwargs["start_at"] = start_at
        super().__init__(kwargs)

        self_.time = time



"""
Create a private location returns "OK" response
"""

from os import environ
from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v1.api.synthetics_api import SyntheticsApi
from datadog_api_client.v1.model.synthetics_private_location import SyntheticsPrivateLocation
from datadog_api_client.v1.model.synthetics_private_location_metadata import SyntheticsPrivateLocationMetadata
from datadog_api_client.v1.model.synthetics_restricted_roles import SyntheticsRestrictedRoles

# there is a valid "role" in the system
ROLE_DATA_ID = environ["ROLE_DATA_ID"]

body = SyntheticsPrivateLocation(
    description="Test Example-Create_a_private_location_returns_OK_response description",
    metadata=SyntheticsPrivateLocationMetadata(
        restricted_roles=SyntheticsRestrictedRoles(
            [
                ROLE_DATA_ID,
            ]
        ),
    ),
    name="Example-Create_a_private_location_returns_OK_response",
    tags=[
        "test:examplecreateaprivatelocationreturnsokresponse",
    ],
)

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = SyntheticsApi(api_client)
    response = api_instance.create_private_location(body=body)

    print(response)



"""
Create a new dashboard returns "OK" response
"""

from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v1.api.dashboards_api import DashboardsApi
from datadog_api_client.v1.model.dashboard import Dashboard
from datadog_api_client.v1.model.dashboard_layout_type import DashboardLayoutType
from datadog_api_client.v1.model.log_query_definition import LogQueryDefinition
from datadog_api_client.v1.model.log_query_definition_group_by import LogQueryDefinitionGroupBy
from datadog_api_client.v1.model.log_query_definition_group_by_sort import LogQueryDefinitionGroupBySort
from datadog_api_client.v1.model.log_query_definition_search import LogQueryDefinitionSearch
from datadog_api_client.v1.model.logs_query_compute import LogsQueryCompute
from datadog_api_client.v1.model.timeseries_widget_definition import TimeseriesWidgetDefinition
from datadog_api_client.v1.model.timeseries_widget_definition_type import TimeseriesWidgetDefinitionType
from datadog_api_client.v1.model.timeseries_widget_request import TimeseriesWidgetRequest
from datadog_api_client.v1.model.widget import Widget
from datadog_api_client.v1.model.widget_sort import WidgetSort

body = Dashboard(
    layout_type=DashboardLayoutType.ORDERED,
    title="Example-Create_a_new_dashboard_returns_OK_response with Profile Metrics Query",
    widgets=[
        Widget(
            definition=TimeseriesWidgetDefinition(
                type=TimeseriesWidgetDefinitionType.TIMESERIES,
                requests=[
                    TimeseriesWidgetRequest(
                        profile_metrics_query=LogQueryDefinition(
                            compute=LogsQueryCompute(
                                aggregation="sum",
                                facet="@prof_core_cpu_cores",
                            ),
                            search=LogQueryDefinitionSearch(
                                query="runtime:jvm",
                            ),
                            group_by=[
                                LogQueryDefinitionGroupBy(
                                    facet="service",
                                    limit=10,
                                    sort=LogQueryDefinitionGroupBySort(
                                        aggregation="sum",
                                        order=WidgetSort.DESCENDING,
                                        facet="@prof_core_cpu_cores",
                                    ),
                                ),
                            ],
                        ),
                    ),
                ],
            ),
        ),
    ],
)

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = DashboardsApi(api_client)
    response = api_instance.create_dashboard(body=body)

    print(response)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    datetime,
    unset,
    UnsetType,
)


class IncidentServiceResponseAttributes(ModelNormal):
    @cached_property
    def openapi_types(_):
        return {
            "created": (datetime,),
            "modified": (datetime,),
            "name": (str,),
        }

    attribute_map = {
        "created": "created",
        "modified": "modified",
        "name": "name",
    }
    read_only_vars = {
        "created",
        "modified",
    }

    def __init__(
        self_,
        created: Union[datetime, UnsetType] = unset,
        modified: Union[datetime, UnsetType] = unset,
        name: Union[str, UnsetType] = unset,
        **kwargs,
    ):
        """
        The incident service's attributes from a response.

        :param created: Timestamp of when the incident service was created.
        :type created: datetime, optional

        :param modified: Timestamp of when the incident service was modified.
        :type modified: datetime, optional

        :param name: Name of the incident service.
        :type name: str, optional
        """
        if created is not unset:
            kwargs["created"] = created
        if modified is not unset:
            kwargs["modified"] = modified
        if name is not unset:
            kwargs["name"] = name
        super().__init__(kwargs)



"""
Get a list of all incident teams returns "OK" response
"""

from os import environ
from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v2.api.incident_teams_api import IncidentTeamsApi

# there is a valid "team" in the system
TEAM_DATA_ATTRIBUTES_NAME = environ["TEAM_DATA_ATTRIBUTES_NAME"]

configuration = Configuration()
configuration.unstable_operations["list_incident_teams"] = True
with ApiClient(configuration) as api_client:
    api_instance = IncidentTeamsApi(api_client)
    response = api_instance.list_incident_teams(
        filter=TEAM_DATA_ATTRIBUTES_NAME,
    )

    print(response)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import List, Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v2.model.events_response_metadata_page import EventsResponseMetadataPage
    from datadog_api_client.v2.model.events_warning import EventsWarning


class EventsResponseMetadata(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v2.model.events_response_metadata_page import EventsResponseMetadataPage
        from datadog_api_client.v2.model.events_warning import EventsWarning

        return {
            "elapsed": (int,),
            "page": (EventsResponseMetadataPage,),
            "request_id": (str,),
            "warnings": ([EventsWarning],),
        }

    attribute_map = {
        "elapsed": "elapsed",
        "page": "page",
        "request_id": "request_id",
        "warnings": "warnings",
    }

    def __init__(
        self_,
        elapsed: Union[int, UnsetType] = unset,
        page: Union[EventsResponseMetadataPage, UnsetType] = unset,
        request_id: Union[str, UnsetType] = unset,
        warnings: Union[List[EventsWarning], UnsetType] = unset,
        **kwargs,
    ):
        """
        The metadata associated with a request.

        :param elapsed: The time elapsed in milliseconds.
        :type elapsed: int, optional

        :param page: Pagination attributes.
        :type page: EventsResponseMetadataPage, optional

        :param request_id: The identifier of the request.
        :type request_id: str, optional

        :param warnings: A list of warnings (non-fatal errors) encountered. Partial results might be returned if
            warnings are present in the response.
        :type warnings: [EventsWarning], optional
        """
        if elapsed is not unset:
            kwargs["elapsed"] = elapsed
        if page is not unset:
            kwargs["page"] = page
        if request_id is not unset:
            kwargs["request_id"] = request_id
        if warnings is not unset:
            kwargs["warnings"] = warnings
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v2.model.security_monitoring_rule_new_value_options_forget_after import (
        SecurityMonitoringRuleNewValueOptionsForgetAfter,
    )
    from datadog_api_client.v2.model.security_monitoring_rule_new_value_options_learning_duration import (
        SecurityMonitoringRuleNewValueOptionsLearningDuration,
    )
    from datadog_api_client.v2.model.security_monitoring_rule_new_value_options_learning_method import (
        SecurityMonitoringRuleNewValueOptionsLearningMethod,
    )
    from datadog_api_client.v2.model.security_monitoring_rule_new_value_options_learning_threshold import (
        SecurityMonitoringRuleNewValueOptionsLearningThreshold,
    )


class SecurityMonitoringRuleNewValueOptions(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v2.model.security_monitoring_rule_new_value_options_forget_after import (
            SecurityMonitoringRuleNewValueOptionsForgetAfter,
        )
        from datadog_api_client.v2.model.security_monitoring_rule_new_value_options_learning_duration import (
            SecurityMonitoringRuleNewValueOptionsLearningDuration,
        )
        from datadog_api_client.v2.model.security_monitoring_rule_new_value_options_learning_method import (
            SecurityMonitoringRuleNewValueOptionsLearningMethod,
        )
        from datadog_api_client.v2.model.security_monitoring_rule_new_value_options_learning_threshold import (
            SecurityMonitoringRuleNewValueOptionsLearningThreshold,
        )

        return {
            "forget_after": (SecurityMonitoringRuleNewValueOptionsForgetAfter,),
            "learning_duration": (SecurityMonitoringRuleNewValueOptionsLearningDuration,),
            "learning_method": (SecurityMonitoringRuleNewValueOptionsLearningMethod,),
            "learning_threshold": (SecurityMonitoringRuleNewValueOptionsLearningThreshold,),
        }

    attribute_map = {
        "forget_after": "forgetAfter",
        "learning_duration": "learningDuration",
        "learning_method": "learningMethod",
        "learning_threshold": "learningThreshold",
    }

    def __init__(
        self_,
        forget_after: Union[SecurityMonitoringRuleNewValueOptionsForgetAfter, UnsetType] = unset,
        learning_duration: Union[SecurityMonitoringRuleNewValueOptionsLearningDuration, UnsetType] = unset,
        learning_method: Union[SecurityMonitoringRuleNewValueOptionsLearningMethod, UnsetType] = unset,
        learning_threshold: Union[SecurityMonitoringRuleNewValueOptionsLearningThreshold, UnsetType] = unset,
        **kwargs,
    ):
        """
        Options on new value rules.

        :param forget_after: The duration in days after which a learned value is forgotten.
        :type forget_after: SecurityMonitoringRuleNewValueOptionsForgetAfter, optional

        :param learning_duration: The duration in days during which values are learned, and after which signals will be generated for values that
            weren't learned. If set to 0, a signal will be generated for all new values after the first value is learned.
        :type learning_duration: SecurityMonitoringRuleNewValueOptionsLearningDuration, optional

        :param learning_method: The learning method used to determine when signals should be generated for values that weren't learned.
        :type learning_method: SecurityMonitoringRuleNewValueOptionsLearningMethod, optional

        :param learning_threshold: A number of occurrences after which signals will be generated for values that weren't learned.
        :type learning_threshold: SecurityMonitoringRuleNewValueOptionsLearningThreshold, optional
        """
        if forget_after is not unset:
            kwargs["forget_after"] = forget_after
        if learning_duration is not unset:
            kwargs["learning_duration"] = learning_duration
        if learning_method is not unset:
            kwargs["learning_method"] = learning_method
        if learning_threshold is not unset:
            kwargs["learning_threshold"] = learning_threshold
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import List, Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.logs_index import LogsIndex


class LogsIndexListResponse(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.logs_index import LogsIndex

        return {
            "indexes": ([LogsIndex],),
        }

    attribute_map = {
        "indexes": "indexes",
    }

    def __init__(self_, indexes: Union[List[LogsIndex], UnsetType] = unset, **kwargs):
        """
        Object with all Index configurations for a given organization.

        :param indexes: Array of Log index configurations.
        :type indexes: [LogsIndex], optional
        """
        if indexes is not unset:
            kwargs["indexes"] = indexes
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


class AWSLogsAsyncError(ModelNormal):
    @cached_property
    def openapi_types(_):
        return {
            "code": (str,),
            "message": (str,),
        }

    attribute_map = {
        "code": "code",
        "message": "message",
    }

    def __init__(self_, code: Union[str, UnsetType] = unset, message: Union[str, UnsetType] = unset, **kwargs):
        """
        Description of errors.

        :param code: Code properties
        :type code: str, optional

        :param message: Message content.
        :type message: str, optional
        """
        if code is not unset:
            kwargs["code"] = code
        if message is not unset:
            kwargs["message"] = message
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations


from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
)


class FunnelStep(ModelNormal):
    @cached_property
    def openapi_types(_):
        return {
            "facet": (str,),
            "value": (str,),
        }

    attribute_map = {
        "facet": "facet",
        "value": "value",
    }

    def __init__(self_, facet: str, value: str, **kwargs):
        """
        The funnel step.

        :param facet: The facet of the step.
        :type facet: str

        :param value: The value of the step.
        :type value: str
        """
        super().__init__(kwargs)

        self_.facet = facet
        self_.value = value



"""
Search events returns "OK" response with pagination
"""

from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v2.api.events_api import EventsApi
from datadog_api_client.v2.model.events_list_request import EventsListRequest
from datadog_api_client.v2.model.events_query_filter import EventsQueryFilter
from datadog_api_client.v2.model.events_query_options import EventsQueryOptions
from datadog_api_client.v2.model.events_request_page import EventsRequestPage
from datadog_api_client.v2.model.events_sort import EventsSort

body = EventsListRequest(
    filter=EventsQueryFilter(
        _from="now-15m",
        to="now",
    ),
    options=EventsQueryOptions(
        timezone="GMT",
    ),
    page=EventsRequestPage(
        limit=2,
    ),
    sort=EventsSort.TIMESTAMP_ASCENDING,
)

configuration = Configuration()
configuration.unstable_operations["search_events"] = True
with ApiClient(configuration) as api_client:
    api_instance = EventsApi(api_client)
    items = api_instance.search_events_with_pagination(body=body)
    for item in items:
        print(item)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations


from datadog_api_client.model_utils import (
    ModelSimple,
    cached_property,
)

from typing import ClassVar


class LogsAggregationFunction(ModelSimple):
    """
    An aggregation function

    :param value: Must be one of ["count", "cardinality", "pc75", "pc90", "pc95", "pc98", "pc99", "sum", "min", "max", "avg", "median"].
    :type value: str
    """

    allowed_values = {
        "count",
        "cardinality",
        "pc75",
        "pc90",
        "pc95",
        "pc98",
        "pc99",
        "sum",
        "min",
        "max",
        "avg",
        "median",
    }
    COUNT: ClassVar["LogsAggregationFunction"]
    CARDINALITY: ClassVar["LogsAggregationFunction"]
    PERCENTILE_75: ClassVar["LogsAggregationFunction"]
    PERCENTILE_90: ClassVar["LogsAggregationFunction"]
    PERCENTILE_95: ClassVar["LogsAggregationFunction"]
    PERCENTILE_98: ClassVar["LogsAggregationFunction"]
    PERCENTILE_99: ClassVar["LogsAggregationFunction"]
    SUM: ClassVar["LogsAggregationFunction"]
    MIN: ClassVar["LogsAggregationFunction"]
    MAX: ClassVar["LogsAggregationFunction"]
    AVG: ClassVar["LogsAggregationFunction"]
    MEDIAN: ClassVar["LogsAggregationFunction"]

    @cached_property
    def openapi_types(_):
        return {
            "value": (str,),
        }


LogsAggregationFunction.COUNT = LogsAggregationFunction("count")
LogsAggregationFunction.CARDINALITY = LogsAggregationFunction("cardinality")
LogsAggregationFunction.PERCENTILE_75 = LogsAggregationFunction("pc75")
LogsAggregationFunction.PERCENTILE_90 = LogsAggregationFunction("pc90")
LogsAggregationFunction.PERCENTILE_95 = LogsAggregationFunction("pc95")
LogsAggregationFunction.PERCENTILE_98 = LogsAggregationFunction("pc98")
LogsAggregationFunction.PERCENTILE_99 = LogsAggregationFunction("pc99")
LogsAggregationFunction.SUM = LogsAggregationFunction("sum")
LogsAggregationFunction.MIN = LogsAggregationFunction("min")
LogsAggregationFunction.MAX = LogsAggregationFunction("max")
LogsAggregationFunction.AVG = LogsAggregationFunction("avg")
LogsAggregationFunction.MEDIAN = LogsAggregationFunction("median")



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


class SecurityFilterMeta(ModelNormal):
    @cached_property
    def openapi_types(_):
        return {
            "warning": (str,),
        }

    attribute_map = {
        "warning": "warning",
    }

    def __init__(self_, warning: Union[str, UnsetType] = unset, **kwargs):
        """
        Optional metadata associated to the response.

        :param warning: A warning message.
        :type warning: str, optional
        """
        if warning is not unset:
            kwargs["warning"] = warning
        super().__init__(kwargs)



"""
Get deleted dashboards returns "OK" response
"""

from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v1.api.dashboards_api import DashboardsApi

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = DashboardsApi(api_client)
    response = api_instance.list_dashboards(
        filter_deleted=True,
    )

    print(response)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    none_type,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.logs_url_parser_type import LogsURLParserType


class LogsURLParser(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.logs_url_parser_type import LogsURLParserType

        return {
            "is_enabled": (bool,),
            "name": (str,),
            "normalize_ending_slashes": (bool, none_type),
            "sources": ([str],),
            "target": (str,),
            "type": (LogsURLParserType,),
        }

    attribute_map = {
        "is_enabled": "is_enabled",
        "name": "name",
        "normalize_ending_slashes": "normalize_ending_slashes",
        "sources": "sources",
        "target": "target",
        "type": "type",
    }

    def __init__(
        self_,
        type: LogsURLParserType,
        is_enabled: Union[bool, UnsetType] = unset,
        name: Union[str, UnsetType] = unset,
        normalize_ending_slashes: Union[bool, none_type, UnsetType] = unset,
        **kwargs,
    ):
        """
        This processor extracts query parameters and other important parameters from a URL.

        :param is_enabled: Whether or not the processor is enabled.
        :type is_enabled: bool, optional

        :param name: Name of the processor.
        :type name: str, optional

        :param normalize_ending_slashes: Normalize the ending slashes or not.
        :type normalize_ending_slashes: bool, none_type, optional

        :param sources: Array of source attributes.
        :type sources: [str]

        :param target: Name of the parent attribute that contains all the extracted details from the ``sources``.
        :type target: str

        :param type: Type of logs URL parser.
        :type type: LogsURLParserType
        """
        if is_enabled is not unset:
            kwargs["is_enabled"] = is_enabled
        if name is not unset:
            kwargs["name"] = name
        if normalize_ending_slashes is not unset:
            kwargs["normalize_ending_slashes"] = normalize_ending_slashes
        super().__init__(kwargs)
        sources = kwargs.get("sources", ["http.url"])
        target = kwargs.get("target", "http.url_details")

        self_.sources = sources
        self_.target = target
        self_.type = type



"""
Change the related incidents of a security signal returns "OK" response
"""

from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v2.api.security_monitoring_api import SecurityMonitoringApi
from datadog_api_client.v2.model.security_monitoring_signal_incident_ids import SecurityMonitoringSignalIncidentIds
from datadog_api_client.v2.model.security_monitoring_signal_incidents_update_attributes import (
    SecurityMonitoringSignalIncidentsUpdateAttributes,
)
from datadog_api_client.v2.model.security_monitoring_signal_incidents_update_data import (
    SecurityMonitoringSignalIncidentsUpdateData,
)
from datadog_api_client.v2.model.security_monitoring_signal_incidents_update_request import (
    SecurityMonitoringSignalIncidentsUpdateRequest,
)

body = SecurityMonitoringSignalIncidentsUpdateRequest(
    data=SecurityMonitoringSignalIncidentsUpdateData(
        attributes=SecurityMonitoringSignalIncidentsUpdateAttributes(
            incident_ids=SecurityMonitoringSignalIncidentIds(
                [
                    2066,
                ]
            ),
        ),
    ),
)

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = SecurityMonitoringApi(api_client)
    response = api_instance.edit_security_monitoring_signal_incidents(
        signal_id="AQAAAYG1bl5K4HuUewAAAABBWUcxYmw1S0FBQmt2RmhRN0V4ZUVnQUE", body=body
    )

    print(response)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.synthetics_ci_batch_metadata_ci import SyntheticsCIBatchMetadataCI
    from datadog_api_client.v1.model.synthetics_ci_batch_metadata_git import SyntheticsCIBatchMetadataGit


class SyntheticsCIBatchMetadata(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.synthetics_ci_batch_metadata_ci import SyntheticsCIBatchMetadataCI
        from datadog_api_client.v1.model.synthetics_ci_batch_metadata_git import SyntheticsCIBatchMetadataGit

        return {
            "ci": (SyntheticsCIBatchMetadataCI,),
            "git": (SyntheticsCIBatchMetadataGit,),
        }

    attribute_map = {
        "ci": "ci",
        "git": "git",
    }

    def __init__(
        self_,
        ci: Union[SyntheticsCIBatchMetadataCI, UnsetType] = unset,
        git: Union[SyntheticsCIBatchMetadataGit, UnsetType] = unset,
        **kwargs,
    ):
        """
        Metadata for the Synthetics tests run.

        :param ci: Description of the CI provider.
        :type ci: SyntheticsCIBatchMetadataCI, optional

        :param git: Git information.
        :type git: SyntheticsCIBatchMetadataGit, optional
        """
        if ci is not unset:
            kwargs["ci"] = ci
        if git is not unset:
            kwargs["git"] = git
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Any, Dict, Union

from datadog_api_client.api_client import ApiClient, Endpoint as _Endpoint
from datadog_api_client.model_utils import (
    UnsetType,
    unset,
)
from datadog_api_client.v1.model.graph_snapshot import GraphSnapshot


class SnapshotsApi:
    """
    Take graph snapshots using the API.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

        self._get_graph_snapshot_endpoint = _Endpoint(
            settings={
                "response_type": (GraphSnapshot,),
                "auth": ["apiKeyAuth", "appKeyAuth", "AuthZ"],
                "endpoint_path": "/api/v1/graph/snapshot",
                "operation_id": "get_graph_snapshot",
                "http_method": "GET",
                "version": "v1",
                "servers": None,
            },
            params_map={
                "metric_query": {
                    "openapi_types": (str,),
                    "attribute": "metric_query",
                    "location": "query",
                },
                "start": {
                    "required": True,
                    "openapi_types": (int,),
                    "attribute": "start",
                    "location": "query",
                },
                "end": {
                    "required": True,
                    "openapi_types": (int,),
                    "attribute": "end",
                    "location": "query",
                },
                "event_query": {
                    "openapi_types": (str,),
                    "attribute": "event_query",
                    "location": "query",
                },
                "graph_def": {
                    "openapi_types": (str,),
                    "attribute": "graph_def",
                    "location": "query",
                },
                "title": {
                    "openapi_types": (str,),
                    "attribute": "title",
                    "location": "query",
                },
                "height": {
                    "openapi_types": (int,),
                    "attribute": "height",
                    "location": "query",
                },
                "width": {
                    "openapi_types": (int,),
                    "attribute": "width",
                    "location": "query",
                },
            },
            headers_map={
                "accept": ["application/json"],
                "content_type": [],
            },
            api_client=api_client,
        )

    def get_graph_snapshot(
        self,
        start: int,
        end: int,
        *,
        metric_query: Union[str, UnsetType] = unset,
        event_query: Union[str, UnsetType] = unset,
        graph_def: Union[str, UnsetType] = unset,
        title: Union[str, UnsetType] = unset,
        height: Union[int, UnsetType] = unset,
        width: Union[int, UnsetType] = unset,
    ) -> GraphSnapshot:
        """Take graph snapshots.

        Take graph snapshots.
        **Note** : When a snapshot is created, there is some delay before it is available.

        :param start: The POSIX timestamp of the start of the query.
        :type start: int
        :param end: The POSIX timestamp of the end of the query.
        :type end: int
        :param metric_query: The metric query.
        :type metric_query: str, optional
        :param event_query: A query that adds event bands to the graph.
        :type event_query: str, optional
        :param graph_def: A JSON document defining the graph. ``graph_def`` can be used instead of ``metric_query``.
            The JSON document uses the `grammar defined here <https://docs.datadoghq.com/graphing/graphing_json/#grammar>`_
            and should be formatted to a single line then URL encoded.
        :type graph_def: str, optional
        :param title: A title for the graph. If no title is specified, the graph does not have a title.
        :type title: str, optional
        :param height: The height of the graph. If no height is specified, the graph's original height is used.
        :type height: int, optional
        :param width: The width of the graph. If no width is specified, the graph's original width is used.
        :type width: int, optional
        :rtype: GraphSnapshot
        """
        kwargs: Dict[str, Any] = {}
        if metric_query is not unset:
            kwargs["metric_query"] = metric_query

        kwargs["start"] = start

        kwargs["end"] = end

        if event_query is not unset:
            kwargs["event_query"] = event_query

        if graph_def is not unset:
            kwargs["graph_def"] = graph_def

        if title is not unset:
            kwargs["title"] = title

        if height is not unset:
            kwargs["height"] = height

        if width is not unset:
            kwargs["width"] = width

        return self._get_graph_snapshot_endpoint.call_with_http_info(**kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v2.model.cloud_workload_security_agent_rule_creator_attributes import (
        CloudWorkloadSecurityAgentRuleCreatorAttributes,
    )
    from datadog_api_client.v2.model.cloud_workload_security_agent_rule_updater_attributes import (
        CloudWorkloadSecurityAgentRuleUpdaterAttributes,
    )


class CloudWorkloadSecurityAgentRuleAttributes(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v2.model.cloud_workload_security_agent_rule_creator_attributes import (
            CloudWorkloadSecurityAgentRuleCreatorAttributes,
        )
        from datadog_api_client.v2.model.cloud_workload_security_agent_rule_updater_attributes import (
            CloudWorkloadSecurityAgentRuleUpdaterAttributes,
        )

        return {
            "category": (str,),
            "creation_date": (int,),
            "creator": (CloudWorkloadSecurityAgentRuleCreatorAttributes,),
            "default_rule": (bool,),
            "description": (str,),
            "enabled": (bool,),
            "expression": (str,),
            "name": (str,),
            "updated_at": (int,),
            "updater": (CloudWorkloadSecurityAgentRuleUpdaterAttributes,),
            "version": (int,),
        }

    attribute_map = {
        "category": "category",
        "creation_date": "creationDate",
        "creator": "creator",
        "default_rule": "defaultRule",
        "description": "description",
        "enabled": "enabled",
        "expression": "expression",
        "name": "name",
        "updated_at": "updatedAt",
        "updater": "updater",
        "version": "version",
    }

    def __init__(
        self_,
        category: Union[str, UnsetType] = unset,
        creation_date: Union[int, UnsetType] = unset,
        creator: Union[CloudWorkloadSecurityAgentRuleCreatorAttributes, UnsetType] = unset,
        default_rule: Union[bool, UnsetType] = unset,
        description: Union[str, UnsetType] = unset,
        enabled: Union[bool, UnsetType] = unset,
        expression: Union[str, UnsetType] = unset,
        name: Union[str, UnsetType] = unset,
        updated_at: Union[int, UnsetType] = unset,
        updater: Union[CloudWorkloadSecurityAgentRuleUpdaterAttributes, UnsetType] = unset,
        version: Union[int, UnsetType] = unset,
        **kwargs,
    ):
        """
        A Cloud Workload Security Agent rule returned by the API.

        :param category: The category of the Agent rule.
        :type category: str, optional

        :param creation_date: When the Agent rule was created, timestamp in milliseconds.
        :type creation_date: int, optional

        :param creator: The attributes of the user who created the Agent rule.
        :type creator: CloudWorkloadSecurityAgentRuleCreatorAttributes, optional

        :param default_rule: Whether the rule is included by default.
        :type default_rule: bool, optional

        :param description: The description of the Agent rule.
        :type description: str, optional

        :param enabled: Whether the Agent rule is enabled.
        :type enabled: bool, optional

        :param expression: The SECL expression of the Agent rule.
        :type expression: str, optional

        :param name: The name of the Agent rule.
        :type name: str, optional

        :param updated_at: When the Agent rule was last updated, timestamp in milliseconds.
        :type updated_at: int, optional

        :param updater: The attributes of the user who last updated the Agent rule.
        :type updater: CloudWorkloadSecurityAgentRuleUpdaterAttributes, optional

        :param version: The version of the Agent rule.
        :type version: int, optional
        """
        if category is not unset:
            kwargs["category"] = category
        if creation_date is not unset:
            kwargs["creation_date"] = creation_date
        if creator is not unset:
            kwargs["creator"] = creator
        if default_rule is not unset:
            kwargs["default_rule"] = default_rule
        if description is not unset:
            kwargs["description"] = description
        if enabled is not unset:
            kwargs["enabled"] = enabled
        if expression is not unset:
            kwargs["expression"] = expression
        if name is not unset:
            kwargs["name"] = name
        if updated_at is not unset:
            kwargs["updated_at"] = updated_at
        if updater is not unset:
            kwargs["updater"] = updater
        if version is not unset:
            kwargs["version"] = version
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations


from datadog_api_client.model_utils import (
    ModelSimple,
    cached_property,
)

from typing import ClassVar


class LogsArchiveState(ModelSimple):
    """
    The state of the archive.

    :param value: Must be one of ["UNKNOWN", "WORKING", "FAILING", "WORKING_AUTH_LEGACY"].
    :type value: str
    """

    allowed_values = {
        "UNKNOWN",
        "WORKING",
        "FAILING",
        "WORKING_AUTH_LEGACY",
    }
    UNKNOWN: ClassVar["LogsArchiveState"]
    WORKING: ClassVar["LogsArchiveState"]
    FAILING: ClassVar["LogsArchiveState"]
    WORKING_AUTH_LEGACY: ClassVar["LogsArchiveState"]

    @cached_property
    def openapi_types(_):
        return {
            "value": (str,),
        }


LogsArchiveState.UNKNOWN = LogsArchiveState("UNKNOWN")
LogsArchiveState.WORKING = LogsArchiveState("WORKING")
LogsArchiveState.FAILING = LogsArchiveState("FAILING")
LogsArchiveState.WORKING_AUTH_LEGACY = LogsArchiveState("WORKING_AUTH_LEGACY")



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.logs_message_remapper_type import LogsMessageRemapperType


class LogsMessageRemapper(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.logs_message_remapper_type import LogsMessageRemapperType

        return {
            "is_enabled": (bool,),
            "name": (str,),
            "sources": ([str],),
            "type": (LogsMessageRemapperType,),
        }

    attribute_map = {
        "is_enabled": "is_enabled",
        "name": "name",
        "sources": "sources",
        "type": "type",
    }

    def __init__(
        self_,
        type: LogsMessageRemapperType,
        is_enabled: Union[bool, UnsetType] = unset,
        name: Union[str, UnsetType] = unset,
        **kwargs,
    ):
        """
        The message is a key attribute in Datadog.
        It is displayed in the message column of the Log Explorer and you can do full string search on it.
        Use this Processor to define one or more attributes as the official log message.

        **Note:** If multiple log message remapper processors can be applied to a given log,
        only the first one (according to the pipeline order) is taken into account.

        :param is_enabled: Whether or not the processor is enabled.
        :type is_enabled: bool, optional

        :param name: Name of the processor.
        :type name: str, optional

        :param sources: Array of source attributes.
        :type sources: [str]

        :param type: Type of logs message remapper.
        :type type: LogsMessageRemapperType
        """
        if is_enabled is not unset:
            kwargs["is_enabled"] = is_enabled
        if name is not unset:
            kwargs["name"] = name
        super().__init__(kwargs)
        sources = kwargs.get("sources", ["msg"])

        self_.sources = sources
        self_.type = type



"""
Check if SLOs can be safely deleted returns "OK" response
"""

from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v1.api.service_level_objectives_api import ServiceLevelObjectivesApi

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = ServiceLevelObjectivesApi(api_client)
    response = api_instance.check_can_delete_slo(
        ids="ids",
    )

    print(response)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations


from datadog_api_client.model_utils import (
    ModelSimple,
    cached_property,
)

from typing import ClassVar


class SyntheticsTestExecutionRule(ModelSimple):
    """
    Execution rule for a Synthetics test.

    :param value: Must be one of ["blocking", "non_blocking", "skipped"].
    :type value: str
    """

    allowed_values = {
        "blocking",
        "non_blocking",
        "skipped",
    }
    BLOCKING: ClassVar["SyntheticsTestExecutionRule"]
    NON_BLOCKING: ClassVar["SyntheticsTestExecutionRule"]
    SKIPPED: ClassVar["SyntheticsTestExecutionRule"]

    @cached_property
    def openapi_types(_):
        return {
            "value": (str,),
        }


SyntheticsTestExecutionRule.BLOCKING = SyntheticsTestExecutionRule("blocking")
SyntheticsTestExecutionRule.NON_BLOCKING = SyntheticsTestExecutionRule("non_blocking")
SyntheticsTestExecutionRule.SKIPPED = SyntheticsTestExecutionRule("skipped")



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.synthetics_ci_batch_metadata_pipeline import SyntheticsCIBatchMetadataPipeline
    from datadog_api_client.v1.model.synthetics_ci_batch_metadata_provider import SyntheticsCIBatchMetadataProvider


class SyntheticsCIBatchMetadataCI(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.synthetics_ci_batch_metadata_pipeline import SyntheticsCIBatchMetadataPipeline
        from datadog_api_client.v1.model.synthetics_ci_batch_metadata_provider import SyntheticsCIBatchMetadataProvider

        return {
            "pipeline": (SyntheticsCIBatchMetadataPipeline,),
            "provider": (SyntheticsCIBatchMetadataProvider,),
        }

    attribute_map = {
        "pipeline": "pipeline",
        "provider": "provider",
    }

    def __init__(
        self_,
        pipeline: Union[SyntheticsCIBatchMetadataPipeline, UnsetType] = unset,
        provider: Union[SyntheticsCIBatchMetadataProvider, UnsetType] = unset,
        **kwargs,
    ):
        """
        Description of the CI provider.

        :param pipeline: Description of the CI pipeline.
        :type pipeline: SyntheticsCIBatchMetadataPipeline, optional

        :param provider: Description of the CI provider.
        :type provider: SyntheticsCIBatchMetadataProvider, optional
        """
        if pipeline is not unset:
            kwargs["pipeline"] = pipeline
        if provider is not unset:
            kwargs["provider"] = provider
        super().__init__(kwargs)
